<?php
/**
 * Customizer functionality
 *
 * @package Zubin
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since 1.0
 *
 * @see wen_commerce_header_style()
 */
function wen_commerce_custom_header_and_bg() {
	$color_scheme       = wen_commerce_get_color_scheme();
	$default_text_color = trim( $color_scheme['header_textcolor'], '#' );

	/**
	 * Filter the arguments used when adding 'custom-background' support in Zubin.
	 *
	 * @since 1.0
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'wen_commerce_custom_bg_args', array(
		'default-color' => '#ffffff',
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Zubin.
	 *
	 * @since 1.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'wen_commerce_custom_header_args', array(
		'default-image'      => get_parent_theme_file_uri( '/images/header-image.jpg' ),
		'default-text-color' => $default_text_color,
		'width'              => 1920,
		'height'             => 656,
		'flex-height'        => true,
		'wp-head-callback'   => 'wen_commerce_header_style',
		'video'              => true,
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/images/header-image.jpg',
			'thumbnail_url' => '%s/images/header-image-275x155.jpg',
			'description'   => esc_html__( 'Default Header Image', 'wen-commerce-pro' ),
		)
	) );
}
add_action( 'after_setup_theme', 'wen_commerce_custom_header_and_bg' );

function wen_commerce_color_options() {
	// We do not add Background Color and Header Text Color here as if comes from WordPress Core.
	$color_options = array(
		'primary_background_color'            => array(
			'label'   => 	esc_html__( 'Primary Background Color', 'wen-commerce-pro' ),
				'css'     =>	'input[type="text"],
								input[type="email"],
								input[type="url"],
								input[type="password"],
								input[type="search"],
								input[type="number"],
								input[type="tel"],
								input[type="range"],
								input[type="date"],
								input[type="month"],
								input[type="week"],
								input[type="time"],
								input[type="datetime"],
								input[type="datetime-local"],
								input[type="color"],
								textarea,
								select,
								:not(.home).navigation-classic .main-navigation a:before,
								.home.navigation-classic .main-navigation a:before,
								.custom-header-form,
								header.site-header.transparent.fixed,
								.demo_store .woocommerce-store-notice__dismiss-link,
								.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
								.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
								.select2-container--default .select2-selection--single,
								.screen-reader-text:focus,
								.boxed-layout .site,
								.why-choose-us-section .hentry .entry-container,
								.ui-state-active,
								.ui-widget-content .ui-state-active,
								#colophon,
								.onsale,
								.product-review-content-wrapper .hentry-inner,
								.product-container  .entry-meta .cat-links a,
								#brands-section .brands-wrapper .entry-header .product_meta a,
								#collection-section .collection-wrapper .entry-header .entry_meta .cat-linnks sa,
								.menu-inside-wrapper .search-form input[type="search"].search-field,
								.menu-inside-wrapper,
								.ui-widget-header .ui-state-active {
								background-color: %1$s;
							}
							@media screen and (min-width: 1200px) {
								.site-header .social-navigation ul,
								.main-navigation ul.sub-menu,
								.header-top-right .top-menu-container ul li ul {
									background-color: %1$s;
								}
							
							}',	
		),
		'secondary_background_color'             => array(
			'label'   => 	esc_html__( 'Secondary Background Color', 'wen-commerce-pro' ),
			'css'     => 	'pre,
							.wp-block-search .wp-block-search__input,
							.testimonial-content-section,
							.woocommerce-Tabs-panel,
							ul.tabs.wc-tabs li.active a,
							.menu-inside-wrapper .mobile-social-search .search-form input[type="search"].search-field,
							.search-form input[type="search"].search-field,
							.comment-respond, .comment-container, 
							.wp-block-latest-comments article, 
							.widget_shopping_cart,
							.widget .ui-tabs .ui-tabs-panel,
							.show-in-mobile .site-header .sub-menu,
							#service-section,
							.search-container,
							form.wpcf7-form,
							.menu-wrapper .social-navigation ul,
							.woocommerce-info, .woocommerce-message,
							.navigation-classic .site-header .children ,
							.post-password-form input[type="password"],
							.footer-newsletter input:not([type="submit"]),
							.custom-header-form input:not([type="submit"]),
							.custom-header-form textarea,
							.team-content-wrapper .entry-container,
							.promotion-section,
							table thead,
							.widget .woocommerce-product-search .search-field,
							.woocommerce #coupon_code,
							mark,
							#testimonial-content-section .owl-prev,
							#testimonial-content-section .owl-next,
							.skillbar-bar:before,
							.skillbar-content,
							.shop_table thead th,
							.widget select,
							.woocommerce .edit-account, 
							.woocommerce-form.woocommerce-form-login.login,
							.woocommerce-account .woocommerce-MyAccount-navigation,
							ul.wc_payment_methods.payment_methods.methods li{
								background-color: %1$s;
							}
							.comment-container::before, 
							.has-avatars.wp-block-latest-comments article::before{
								border-right-color: %1$s;
							}',
		),
		'tertiary_background_color' => array(
			'label'   => 	esc_html__( 'Tertiary Background Color', 'wen-commerce-pro' ),
			'css'     => 	'#gallery-section .gallery-item .gallery-icon a:before,
							#header-top,
							ins,
							.custom-header,
							.social-links-menu li a,
							#countdown-section,
							.site-header-cart .cart-wrapper ul li a.remove:hover,
							#gallery-section .tiled-gallery .tiled-gallery-item a:before,
							.owl-carousel .owl-dots button.owl-dot span  {
								background-color: %1$s;
							}',
		),
		'main_text_color'          => array(
			'label'   => 	esc_html__( 'Main Text Color', 'wen-commerce-pro' ),
			'css'     => 	'body,
							input,
							select,
							optgroup,
							textarea,
							table a,
							blockquote,
							.navigation-classic header.fixed .main-navigation .nav-menu > li > a,
							header.fixed button.menu-toggle,
							header.fixed button.menu-toggle .menu-label,
							header.fixed #site-header-cart-wrapper a.cart-contents,
							.fixed .site-description,
							.custom-header-content-wrapper .more-link,
							.skill-section.has-background-image .entry-summary,
							.skill-section.has-background-image .entry-content,
							input[type="text"],
							input[type="email"],
							input[type="url"],
							input[type="password"],
							input[type="search"],
							input[type="number"],
							input[type="tel"],
							input[type="range"],
							input[type="date"],
							input[type="month"],
							input[type="week"],
							input[type="time"],
							input[type="datetime"],
							input[type="datetime-local"],
							input[type="color"],
							.position,
							.testimonial-content-section .testimonial-slider .entry-content h4,
							#testimonial-content-section .entry-meta,
							.section-description-wrapper,
							.section-title-wrapper+.section-description,
							.section-heading-wrapper>.section-description,
							.skill-section.has-background-image .section-heading-wrapper>.section-description,
							.section-title+.section-description,
							#testimonial-content-section .entry-title
							.product-content-section span.woocommerce-Price-amount,
							.sidebar .widget-wrap p,
							#promotion-section .play-video .play-button:hover:before,
							#promotion-section .play-video .play-button:focus:before,
							.entry-container .entry-content,
							.product-container span.price,
							.price del + ins,
							.product_list_widget ins,
							.product-review-content-wrapper h2.entry-title,
							.entry-container .entry-summary{
								color: %1$s;
							}',
		),

		'secondary_text_color'         => array(
			'label'   => 	esc_html__( 'Secondary Text Color', 'wen-commerce-pro' ),
			'css'     => 	'pre,
							.site-footer .widget-wrap .widget-title,
							aside.footer-widget-area .widget-title,
							blockquote p,
							#comments .description p,
							strong,
							.has-header-image .custom-header-content-wrapper .more-link,
							.menu-label  {
							    color: %1$s;
							}',

		),

		'heading_text_color'         => array(
			'label'   => 	esc_html__( 'Heading Text Color', 'wen-commerce-pro' ),
			'css'     => 	'h1,
							h2,
							h3,
							h4,
							h5,
							h6,
							.custom-header .entry-breadcrumbs a,
							.skill-section.has-background-image .section-heading-wrapper .section-title,
							.skill-section.has-background-image .entry-container .section-title,
							.skill-section.has-background-image .entry-container .section-description,
							.portfolio-content-wrapper .filter-button-group button,
							.testimonial-content-section.section .owl-carousel .owl-nav button.owl-next, 
							.testimonial-content-section.section .owl-carousel .owl-nav button.owl-prev,
							.author-name,
							.comment-reply-link,
							.author-title,
							#testimonial-content-section .entry-title,
							.comments-title,
							.comment-reply-title,
							#review_form_wrapper label,
							.comment-respond .comment-form p label,
							.section-title,
							.woocommerce legend,
							.woocommerce form label,
							.portfolio-section-headline .section-title,
							.entry-title a,
							.drop-cap:first-letter  {
							    color: %1$s;
							}

							@media screen and (min-width: 1200px) {
 
								.header-top-right .top-menu-container ul li ul a{
									  color: %1$s;
								}							
							}',
		),
		'header_navigation_color'         => array(
			'label'   => 	esc_html__( 'Header Navigation Color', 'wen-commerce-pro' ),
			'css'     => 	'.main-navigation ul a,
							.site-header-cart > li > a,
							.site-header .menu-label,
							.site-header-cart .cart-contents,
							.menu-toggle{
							    color: %1$s;
							}',
		),

		'header_navigation_hover_color'               => array(
			'label'   => 	esc_html__( 'Header Navigation Hover Color', 'wen-commerce-pro' ),
			'css'     => 	'.menu-toggle:hover,
							.menu-toggle:focus,
							.cart-contents:hover,
							.cart-contents:focus,
							.site-header-cart > li > a:hover,
							.site-header-cart > li > a:focus,
							.site-header-cart .cart-contents:hover,
							.site-header-cart .cart-contents:focus,
							.site-header-menu .main-navigation a:hover,
							.site-header-menu .main-navigation a:focus,
							.site-header-menu .social-navigation a:hover,
							.site-header-menu .social-navigation a:focus,
							.dropdown-toggle:hover,
							.dropdown-toggle:focus,
							.site-header-menu .main-navigation .current_page_item > a,
							.site-header-menu .main-navigation .current-menu-item > a,
							.main-navigation ul ul .current_page_item > a,
							.main-navigation ul ul .current-menu-item > a,
							.main-navigation .nav-menu > li.current-menu-item >a,
							.site-header-cart .cart-contents:hover .count,
							.site-header-cart .cart-contents:focus .count,
							.menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a,
							button.dropdown-toggle:hover,
							button.dropdown-toggle:focus,
							.menu-toggle:hover .menu-label,
							.menu-toggle:focus .menu-label, 
							.main-navigation .nav-menu > li > a:hover,
							.main-navigation .nav-menu > li > a:focus{
							        color: %1$s;
							}',
		),
	
		
		'header_media_slider_text_color'    => array(
			'label'   => 	esc_html__( 'Header Media Slider Text Color', 'wen-commerce-pro' ),
			'css'     => 	'.has-header-image .custom-header .breadcrumb-area .entry-breadcrumbs,
							.has-header-image .custom-header .breadcrumb-area .entry-breadcrumbs a,
							.has-header-image .custom-header .breadcrumb-area .woocommerce-breadcrumb,
							.custom-header-content .entry-title .sub-title, 
							.feature-slider-wrapper .entry-container .entry-title,
							.feature-slider-wrapper .entry-container .entry-title span,
							.feature-slider-wrapper .entry-container .entry-summary,
							.feature-slider-wrapper .entry-container .entry-content,
							#feature-slider-section .description,
							.play-button-text,
							.slider-content-wrapper .entry-meta .byline span.author a,
							.has-header-image .custom-header-content .site-header-text,
							.has-header-image .custom-header-content .site-header-text .entry-meta a,
							.has-header-image .custom-header-content .section-title{
							    color: %1$s;
							}',
		),

		'link_color'         => array(
			'label'   => 	esc_html__( 'Link Color', 'wen-commerce-pro' ),
			'css'     => 	'a {
								color: %1$s;
							}',
		),
		'link_hover_color'         => array(
			'label'   => 	esc_html__( 'Link Hover Color', 'wen-commerce-pro' ),
			'css'     => 	'a:hover,
							a:focus {
							    color: %1$s;
							}',

		),
		'secondary_link_color'           => array(
			'label'   => 	esc_html__( 'Secondary Link Color', 'wen-commerce-pro' ),
			'css'     => 	'.entry-title a,
							.service-section .more-link,
							.stats-section p:not(.view-more) .more-link,
							.featured-content-section .more-link,
							.sidebar .widget-wrap li a,
							.dropdown-toggle,
							.site-header-menu .menu-inside-wrapper .nav-menu li button,
							.ui-state-active a,
							.ui-state-active a:link,
							.ui-state-active a:visited,
							.social-search-wrapper .menu-social-container li a,
							.sidebar nav.social-navigation ul li a:hover,
							.sidebar nav.social-navigation ul li a:focus,
							.screen-reader-text:focus,
							td#today,
							th,
							dt,
							table caption,
							#stats-section .entry-title a:hover,
							#stats-section .entry-title a:focus,
							.toggled-on.active:before,
							.comment-respond .comment-form p.is-focused label,
							.contact-section.section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li a,
							.nav-title,
							.post-title,
							.woocommerce.has-header-image .woocommerce-breadcrumb a:hover,
							.woocommerce.has-header-image .woocommerce-breadcrumb a:focus,
							.sidebar .widget .more-link .more-button,
							#collection-section .collection-wrapper .entry-meta a,
							#brands-section .brands-wrapper .entry-header .product_meta a,
							#contact-section .hentry label,
							.comment-meta .author-name a,
							.widget_recent_entries li a,
							input::placeholder,
							textarea::placeholder,
							.testimonial-content-section .entry-meta span,
							.job-label,
							.entry-breadcrumbs a,
							.woocommerce.woocommerce-active .woocommerce-breadcrumb a,
							p.stars a,
							p.stars a:before,
							.controller:before,
							.select2-results__option,
							body.no-header-media-image .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu .current_page_item > a,
							#footer-newsletter .wrapper .section-description,
							.widget-wrap span.post-date,
							.contact-section .entry-container a,
							.archive .section-content-wrapper .more-link .readmore,
							.archive-post-wrap .more-link,
							.faq-section .hentry .more-link,
							.team-section .hentry .more-link,
							.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:before,
							.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:after,
							.testimonials-content-wrapper.section.testimonial-wrapper .cycle-next:before,
							.clients-content-wrapper .controller .cycle-pager span,
							.testimonials-content-wrapper .cycle-pager:after,
							.slider-content-wrapper .entry-container .entry-container-wrap .entry-summary,
							.testimonials-content-wrapper .entry-title a,
							.testimonials-content-wrapper.section.testimonial-wrapper .hentry,
							.scrollup a:hover:before,
							.scrollup a:focus:before,
							.sidebar .widget-wrap .more-link,
							.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
							.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
							.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a,
							.team-section .entry-meta,
							.author-label,
							.author-section-title,
							.comment-permalink,
							.comment-edit-link,
							.entry-title span,
							.nav-subtitle,
							.nav-menu .menu-item-has-children>a:before,
							.nav-menu .menu_item_has_children>a:before,
							.breadcrumb-area .entry-breadcrumbs,
							.breadcrumb-area .woocommerce-breadcrumb,
							.vcard,
							.entry-meta a,
							.woocommerce-tabs ul.tabs li a,
							.tagcloud a,
							.woocommerce-account .woocommerce-MyAccount-navigation a,
							.product-container .entry-header .entry-meta .cat-links a,
							.entry-meta .cat-links a, .page-links a {
								color: %1$s;
							}

							.tag-cloud-link,
							.widget-area .essential-widgets .tagcloud a, 
							.wp-block-tag-cloud a, 
							.sidebar .tagcloud a {
								border-color: %1$s;
							}

							.entry-header .entry-meta > span::before{
								background-color:  %1$s;
							}',
		),

		'secondary_link_hover_color'           => array(
			'label'   => 	esc_html__( 'Secondary Link Hover Color', 'wen-commerce-pro' ),
			'css'     => 	'.site-info a:hover,
							.site-info a:focus,
							.post-title:hover,
							.post-title:focus,
							.play-button-text:hover,
							.play-button-text:focus,
							.sidebar .widget-wrap li a:hover,
							.sidebar .widget-wrap li a:focus,
							.woocommerce .woocommerce-breadcrumb a:hover,
							.woocommerce .woocommerce-breadcrumb a:focus,
							.has-background-image .woocommerce-loop-product__title:hover,
							.has-background-image .woocommerce-loop-product__title:focus,
							.has-background-image  .entry-container .entry-meta a:hover,
							.has-background-image  .entry-container .entry-meta a:focus,
							.has-background-image  .entry-container .entry-title a:hover,
							.has-background-image  .entry-container .entry-title a:focus,
							.single footer .entry-meta a:hover,
							.single footer .entry-meta a:focus,
							#site-footer-navigation li a:hover,
							#site-footer-navigation li a:focus,
							.has-background-image .entry-title a:hover,
							.has-background-image .entry-title a:focus,
							.has-background-image .entry-meta a:hover,
							.has-background-image .entry-meta a:focus,
							.archive-post-wrap .hentry:nth-child(2n) .entry-title a:hover,
							.archive-post-wrap .hentry:nth-child(2n) .entry-title a:focus,
							.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:hover,
							.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:focus,
							.team-content-wrapper .entry-container .entry-title a:hover,
							.team-content-wrapper .entry-container .entry-title a:focus,
							.team-content-wrapper .entry-container .entry-meta a:hover,
							.team-content-wrapper .entry-container .entry-meta a:focus,
							.team-content-wrapper .entry-container .social-navigation a:hover,
							.team-content-wrapper .entry-container .social-navigation a:focus,
							.wp-playlist-tracks .wp-playlist-caption:hover,
							.wp-playlist-tracks .wp-playlist-caption:focus,
							#service-section .entry-title a:hover,
							#service-section .entry-title a:focus,
							.woocommerce-loop-product__title:hover,
							.woocommerce-loop-product__title:focus,
							span.price span.woocommerce-Price-amount:hover,
							span.price span.woocommerce-Price-amount:focus,
							.events-content-wrapper .entry-meta a:hover,
							.events-content-wrapper .entry-meta a:focus,
							.widget_recent_entries li a:hover,
							.widget_recent_entries li a:focus,
							.portfolio-content-wrapper .hentry .entry-container a:hover,
							.portfolio-content-wrapper .hentry .entry-container a:focus,
							button#wp-custom-header-video-button:hover,
							button#wp-custom-header-video-button:focus,
							.widget .ui-state-default a:hover,
							.widget .ui-state-default a:focus,
							.widget .ui-widget-content .ui-state-default a:hover,
							.widget .ui-widget-content .ui-state-default a:focus,
							.widget .ui-widget-header .ui-state-default a:hover,
							.widget .ui-widget-header .ui-state-default a:focus,
							.nav-title:hover,
							.nav-title:focus,
							.menu-social-container a:hover,
							.menu-social-container a:focus,
							.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:hover,
							.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:focus,
							.portfolio-content-wrapper .hentry .entry-container a:hover,
							.portfolio-content-wrapper .hentry .entry-container a:focus,
							.portfolio-content-wrapper .hentry .entry-container .entry-meta time:hover,
							.portfolio-content-wrapper .hentry .entry-container .entry-meta time:focus,
							.social-search-wrapper .menu-social-container li a:hover,
							.social-search-wrapper .menu-social-container li a:focus,
							.sidebar .widget-wrap .more-link:hover,
							.sidebar .widget-wrap .more-link:focus,
							.featured-content-section .hentry .more-link:hover,
							.featured-content-section .hentry .more-link:focus,
							#portfolio-content-section .more-link:hover,
							#portfolio-content-section .more-link:focus,
							.author a:hover,
							.author a:focus,
							.entry-title a:hover,
							.entry-title a:focus,
							.site-footer td#prev a:hover,
							.site-footer td#prev a:focus,
							.site-footer td#next a:hover,
							.site-footer td#next a:focus,
							.comment-reply-link:hover,
							.comment-reply-link:focus,
							aside.footer-widget-area a:hover,
							aside.footer-widget-area a:focus,
							.portfolio-content-wrapper .filter-button-group button:hover,
							.portfolio-content-wrapper .filter-button-group button:focus,
							.author-section-title:hover,
							.author-section-title:focus,
							.comment-permalink:hover,
							.comment-permalink:focus,
							.comment-edit-link:hover,
							.comment-edit-link:focus,
							.nav-subtitle:hover,
							.nav-subtitle:focus,
							.entry-meta a:hover,
							.entry-meta a:focus,
							.scroll-down:hover,
							.scroll-down:focus,
							.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:hover,
							.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:focus,
							#site-generator .menu-social-container a:hover,
							#site-generator .menu-social-container a:focus,
							.widget-wrap li a:hover,
							.widget-wrap li a:focus,
							#featured-content-section .section-content-wrapper .hentry .more-link:hover,
							#featured-content-section .section-content-wrapper .hentry .more-link:focus,
							.service-section .hentry .more-link:hover,
							.service-section .hentry .more-link:focus,
							#portfolio-content-section .hentry .more-link:hover,
							#portfolio-content-section .hentry .more-link:focus,
							#service-section.has-background-image .hentry .more-link:hover,
							#service-section.has-background-image .hentry .more-link:focus,
							#stats-section .hentry .more-link:hover,
							#stats-section .hentry .more-link:focus,
							#service-section .hentry .more-link:hover,
							#service-section .hentry .more-link:focus,
							.navigation.pagination a:hover,
							.navigation.pagination a:focus,
							.breadcrumb a:hover,
							.breadcrumb a:focus,
							.contact-details a:hover,
							.contact-details a:focus,
							aside.footer-widget-area .social-navigation a:hover,
							aside.footer-widget-area .social-navigation a:focus,
							.sidebar .widget .more-link .more-button:hover,
							.sidebar .widget .more-link .more-button:focus,
							.header-top-right .top-menu-container ul li ul a:hover,
							.header-top-right .top-menu-container ul li ul a:focus,
							.header-top-bar .site-navigation a:hover,
							.header-top-bar .site-navigation a:focus,
							.more-link:hover,
							.more-link:focus,
							.entry-meta .cat-links a:hover,
							.entry-meta .cat-links a:focus,
							.woocommerce-tabs ul.tabs li a:hover,
							.woocommerce-tabs ul.tabs li a:focus,
							.tagcloud a:hover,
							.tagcloud a:focus,
							span.page-numbers.dots:hover,
							span.page-numbers.dots:focus,
							.site-title a:hover,
							.site-title a:focus,
							.archive-post-wrap .more-link:hover,
							.archive-post-wrap .more-link:span,
							.woocommerce-account .woocommerce-MyAccount-navigation a:hover,
							.woocommerce-account .woocommerce-MyAccount-navigation a:focus,
							.brands-wrapper .product-container .entry-title a:hover,
							.brands-wrapper .product-container .entry-title a:focus,
							.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:hover,
							.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:focus {
								color:  %1$s;
							}

							.top-navigation a:hover,
							.top-navigation a:focus,
							.header-top-bar .social-navigation a:hover,
							.header-top-bar .social-navigation a:focus,
							.service-section .more-link:hover,
							.service-section .more-link:focus,
							.header-top-bar .menu-toggle:hover,
							.header-top-bar .menu-toggle:focus,
							.has-header-image .custom-header .breadcrumb-area .entry-breadcrumbs a:hover,
							.has-header-image .custom-header .breadcrumb-area .entry-breadcrumbs a:focus,
							.custom-header .entry-breadcrumbs a:hover,
							.custom-header .entry-breadcrumbs a:focus,
							.has-header-image .custom-header-content .site-header-text .entry-meta a:hover,
							.has-header-image .custom-header-content .site-header-text .entry-meta a:focus,
							.header-media .custom-header-content-wrapper .more-link:hover,
							.header-media .custom-header-content-wrapper .more-link:focus,
							.stats-section p:not(.view-more) .more-link:hover,
							.stats-section p:not(.view-more) .more-link:focus,
							.featured-content-section .more-link:hover,
							.featured-content-section .more-link:focus,
							p.stars:hover a:before,
							p.stars:focus a:before,
							.star-rating span:before,
							p.stars.selected a.active:before,
							p.stars.selected a:not(.active):before,
							p.stars.selected a.active~a:before,
							p.stars a:hover~a:before,
							p.stars a:focus~a:before,
							#reviews .comment-respond .comment-form-rating .stars span a.active:before,
							.page-numbers.current,
							.page-links .current,
							blockquote:before,
							p a,
							li a,
							dl a,
							dd a,
							.entry-header .entry-meta .cat-links a,
							.more-button:hover,
							ul li::marker,
							.pagination span.page-numbers.current,
							.onsale,
							.woocommerce-tabs ul.tabs li.active a,
							.entry-header .entry-meta > span.cat-links,
							#stats-section .entry-title a:hover,
							.slider-content-wrapper .entry-meta .byline span.author a:hover,
							.comment-meta .author-name a:hover,
							#menu-toggle-top:hover .header-top-label,
							.collection-wrapper .entry-container .entry-title a:hover,
							.post-navigation .nav-links a:hover .nav-title,
							.entry-title .sub-title,
							.section-subtitle,
							.section-title-wrapper+.section-subtitle,
							.section-heading-wrapper>.section-subtitle,
							.logo-slider-section:hover button:hover:before,
							.logo-slider-section:hover button:focus:before,
							.skill-section.has-background-image .section-heading-wrapper > .section-subtitle,
							.section-heading-wrapper .sub-title,
							.section-heading-wrapper .entry-title span,
							#collection-section .product-container .woocommerce-loop-product__title a:hover,
							#brands-section .product-container .woocommerce-loop-product__title a:hover,
							.woocommerce-account .woocommerce-MyAccount-navigation a,
							#reviews .comment-respond .comment-form-rating .stars.selected span a:not(.active):before   {
							    color: %1$s;
							}

							.widget-area .essential-widgets .tagcloud a:hover, 
							input:focus,.entry-meta .cat-links a:hover, 
							.pagination span.page-numbers.current,
							.entry-footer .entry-meta .cat-links a:hover,
							#footer-newsletter .ewnewsletter .hentry form input.ew-newsletter-subbox:focus, 
							textarea:focus, .pagination .page-numbers:hover, .sidebar .tagcloud a:hover, .wp-block-tag-cloud a:hover, 
							.widget .woocommerce-product-search .search-field:focus,
							.woocommerce #coupon_code:focus,
							.search-form input[type="search"].search-field:focus,
							.entry-footer .cat-links a:hover, .page-links a:hover,  
							#contact-section .hentry input:not([type="submit"]):focus, 
							#contact-section .hentry textarea:focus,input[type="date"]:focus, 
							input[type="time"]:focus, 
							input[type="datetime-local"]:focus, 
							input[type="week"]:focus, 
							input[type="month"]:focus, 
							input[type="text"]:focus, input[type="email"]:focus, 
							input[type="url"]:focus, input[type="password"]:focus, 
							input[type="search"]:focus, input[type="tel"]:focus, 
							input[type="number"]:focus, textarea:focus {
								border-color: %1$s;
							}',
		),

		'tertiary_link_color'           => array(
			'label'   => 	esc_html__( 'Tertiary Link Color', 'wen-commerce-pro' ),
			'css'     => 	'.ewabout p,
							aside.footer-widget-area svg,
							aside.footer-widget-area a,
							aside.footer-widget-area p,
							.site-info,
							.site-info a,
							.archive-posts-wrapper .entry-header .entry-meta .cat-links a:hover,
							#site-footer-navigation li a,
							.section .owl-carousel .owl-nav button.owl-next, 
							.section .owl-carousel .owl-nav button.owl-prev{
								color:  %1$s;
							}',
		),
		'border_color'             => array(
			'label'   => 	esc_html__( 'Border Color', 'wen-commerce-pro' ),
			'css'     => 	'nav.navigation,
							div#site-generator:before,
							.woocommerce-ordering select,
							#stats-section .section-content-wrapper:before,
							.logo-slider-section .section-content-wrapper:before,
							.site-content .archive-posts-wrapper .posts-navigation .nav-links .nav-previous,
							.calendar_wrap tbody tr:first-child,
							.calendar_wrap tbody tr:last-child,
							tfoot,
							tfoot tr td,
							.author-info,
							.wpcf7 div input, 
							.wpcf7 div textarea,
							#promotion-section .play-button,
							.navigation-classic .main-navigation ul ul,
							.woocommerce-shorting-wrapper,
							.woocommerce-tabs ul.tabs.wc-tabs li,
							.menu-wrapper .widget_shopping_cart ul.woocommerce-mini-cart li,
							.entry-summary form.cart,
							.widget_recent_entries li,
							.team-section .team-content-wrapper .hentry .team-social-profile .social-links-menu,
							input[type="submit"],
							input[type="url"],
							input[type="search"],
							input[type="number"],
							input[type="tel"],
							input[type="range"],
							input[type="date"],
							input[type="month"],
							input[type="week"],
							input[type="time"],
							input[type="datetime"],
							input[type="datetime-local"],
							input[type="color"],
							table,
							caption,
							.sidebar.widget-area .widget-wrap,
							table th,
							table thead tr,
							table thead th,
							thead th,
							tbody th,
							tbody td,
							tbody tr,
							table.shop_table_responsive tr td,
							table tbody tr,
							table.shop_table_responsive tbody tr:last-child,
							.shop_table tfoot tr td,
							.shop_table tfoot tr th,
							table.shop_table.woocommerce-checkout-review-order-table .cart_item td,
							table.shop_table.woocommerce-checkout-review-order-table tr td,
							table.shop_table.woocommerce-checkout-review-order-table tr th,
							.rtl tbody td:last-child,
							.rtl table thead th:last-child,
							.select2-container--default .select2-selection--single,
							table.woocommerce-grouped-product-list.group_table,
							table.woocommerce-grouped-product-list.group_table td,
							table.variations,
							table.variations td,
							.woocommerce-pagination ul.page-numbers li .page-numbers,
							.archive-content-wrap .navigation.pagination .page-numbers,
							.woocommerce-posts-wrapper .summary.entry-summary .woocommerce-product-rating,
							.cart-collaterals .order-total,
							#payment .wc_payment_methods .payment_box,
							.products .product,
							select,
							header .site-header-main,
							abbr,
							acronym,
							.archive-post-wrap .hentry .hentry-inner,
							.product-quantity input[type="number"],
							.coupon input[type="text"],
							.site-header-main .menu-inside-wrapper,
							.site-header-cart .widget_shopping_cart,
							.woocommerce-grouped-product-list tr,
							.mobile-social-search,
							.widget .ui-tabs .ui-tabs-panel,
							#colophon,
							.site-header-menu .menu-inside-wrapper .nav-menu button:focus,
							header .site-header-menu .menu-inside-wrapper .main-navigation .sub-menu li:last-child,
							header .site-header-menu .menu-inside-wrapper .main-navigation .children li:last-child,
							.comment-body,
							.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link,
							.section:nth-child(2n) + .site-content,
							.post-navigation a,
							.product-review-content-wrapper .hentry-inner,
							.quantity .qty,
							.woocommerce-account .woocommerce-MyAccount-navigation li,
							aside.widget-area + div#site-generator:before,
							#footer-newsletter .ewnewsletter .hentry form input.ew-newsletter-subbox,
							.archive-content-wrap .section-content-wrapper.layout-one .hentry .hentry-inner .entry-container>.entry-meta,
							.team-content-wrapper .entry-container,
							.tag-cloud-link,
							cite,
							.widget-area .essential-widgets .tagcloud a, 
							.entry-footer .entry-meta .cat-links a, 
							.wp-block-tag-cloud a, 
							.sidebar .tagcloud a, 
							.pagination .page-numbers,
							.page .site-main .entry-footer .entry-meta > span:not(.edit-link),
							.single .site-main .entry-footer .entry-meta > span:not(.edit-link),
							.events-content-wrapper .hentry,
							.testimonial-content-section + .service-section,
							.product-review-section .entry-content .attachment-woocommerce_thumbnail img,
							.section:not(#promotion-section):not(#testimonial-content-section):not(#service-section):not(#countdown-section) + .site-footer, 
							#footer-newsletter + .site-footer,
							#site-generator > .wrapper:before,
							.comments-area {
							    border-color: %1$s;
							}',
		),

		'button_background_color'          => array(
			'label'   => 	esc_html__( 'Button Background Color', 'wen-commerce-pro' ),
			'css'     => 	'.feature-slider-wrapper a.more-link,
							#hero-section .view-more a.more-link,
							.button,
							.navigation-classic .main-navigation a:before,
							:not(.home).navigation-classic .fixed .main-navigation a:before,
							.absolute-header.navigation-classic .fixed .main-navigation a:before,
							.home.navigation-classic .fixed .main-navigation a:before,
							.absolute-header.navigation-classic .main-navigation a:before,
							.demo_store,
							.entry-content button,
							.entry-summary button,
							button,
							#scrollup,
							.portfolio-content-wrapper .filter-button-group button.is-checked,
							.slider-content-wrapper .controllers .cycle-prev,
							.slider-content-wrapper .controllers .cycle-next,
							input[type="submit"],
							button[type="submit"],
							.scrollup a,
							.sticky-post,
							#team-dots li.active:after,
							#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover,
							#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus,
							.wp-block-button__link,
							#infinite-handle .ctis-load-more button,
							.menu-inside-wrapper #site-header-cart-wrappe li>a,
							.contact-section .entry-container ul.contact-details li .fa,
							nav.navigation.posts-navigation .nav-links a,
							.woocommerce-pagination ul.page-numbers li .page-numbers.current,
							.archive-content-wrap .pagination .page-numbers.current,
							.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
							.sticky-label,
							.logo-slider-section .owl-dots .owl-dot span,
							.woocommerce .products .product-container .button,
							blockquote.alignright:after,
							blockquote.alignleft:after,
							#testimonial-content-section .owl-prev:hover,
							#testimonial-content-section .owl-prev:focus,
							#testimonial-content-section .owl-next:hover,
							#testimonial-content-section .owl-next:focus,
							#feature-slider-section .owl-nav button:hover,
							#feature-slider-section .owl-nav button:focus,
							a.next.page-numbers,
							a.prev.page-numbers,
							.woocommerce .product-container .added_to_cart.wc-forward,
							#testimonial-content-section .section-content-wrapper .entry-content:before,
							.logo-slider-section .owl-carousel .owl-nav .owl-prev:hover,
							.logo-slider-section .owl-carousel .owl-nav .owl-prev:focus,
							.logo-slider-section .owl-carousel .owl-nav .owl-next:hover,
							.logo-slider-section .owl-carousel .owl-nav .owl-next:focus,
							.site-header-cart .cart-contents .count,
							.promotion-section .more-link,
							.more-link .more-button,
							.skillbar-item .skillbar-bar:before,
							.product-container .button:hover,
							.brands-wrapper .entry-summary p a:hover,
							.home .header-media-section a.more-link,
							#collection-section .collection-wrapper .entry-meta a:hover,
							#brands-section .brands-wrapper .entry-header .product_meta a:hover,
							.product-container .entry-header .entry-meta .cat-links a:hover,
							.widget-area:not(.sidebar) .widget .widget-title:after {
							    background-color: %1$s;
							}
							
							blockquote.alignright,
							blockquote.alignleft,
							.owl-carousel .owl-dots button.owl-dot.active span,
							.team-content-wrapper.section-content-wrapper .hentry-inner .entry-container,
							#hero-section .hentry .entry-container blockquote,
							.logo-slider-section .owl-prev:hover,
							.logo-slider-section .owl-prev:focus,
							.logo-slider-section .owl-next:hover,
							.logo-slider-section .owl-next:focus,
							#testimonial-content-section .section-content-wrapper .entry-summary:after,
							#testimonial-content-section .section-content-wrapper .entry-content:after,
							.woocommerce-info, 
							.woocommerce-message,
							.woocommerce .products .product-container .button,
							.logo-slider-section .owl-dots .owl-dot.active span  {
							    border-color: %1$s;
							 }',
		),
		'button_text_color'        => array(
			'label'   => 	esc_html__( 'Button Text Color', 'wen-commerce-pro' ),
			'css'     => 	'.more-link,
							.more-button,
							.entry-content button,
							.entry-summary button,
							.slider-content-wrapper .controllers .cycle-prev,
							.slider-content-wrapper .controllers .cycle-next,
							button,
							#scrollup,
							#primary-search-wrapper .search-container button,
							input[type="submit"],
							.button,
							.scroll-down,
							.scrollup a:before,
							.page-numbers:hover,
							.page-numbers:focus,
							button[type="submit"],
							button#wp-custom-header-video-button,
							#infinite-handle .ctis-load-more button,
							nav.navigation.posts-navigation .nav-links a,
							.woocommerce-pagination ul.page-numbers li:hover,
							.archive-content-wrap .pagination .page-numbers:hover,
							.archive-content-wrap .pagination .page-numbers:focus,
							.woocommerce-pagination ul.page-numbers li:focus,
							.archive-content-wrap .pagination .page-numbers.current,
							.woocommerce-pagination ul.page-numbers li .page-numbers.current,
							#portfolio-content-section .entry-container,
							.contact-details li .fa,
							.feature-slider-wrapper .entry-container .more-link,
							.slider-content-wrapper #featured-slider-prev:hover:before,
							.slider-content-wrapper #featured-slider-next:hover:before,
							.slider-content-wrapper #featured-slider-prev:focus:before,
							.slider-content-wrapper #featured-slider-next:focus:before,
							#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover:before,
							#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus:before,
							.nav-menu .menu-item-has-children>a:hover:before,
							.nav-menu .menu-item-has-children>a:focus:before,
							.nav-menu .menu_item_has_children>a:hover:before,
							.nav-menu .menu_item_has_children>a:focus:before,
							.contact-section .entry-container ul.contact-details li .fa,
							.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
							.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover a,
							.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus a {
								color: %1$s;
							}',
		),

		'button_text_hover_color'  => array(
			'label'   => 	esc_html__( 'Button Hover Text Color', 'wen-commerce-pro' ),
			'css'     => 	'button:hover,
							button:focus,
							.button:hover,
							.button:focus,
							.entry-content button:hover,
							.entry-content button:focus,
							.entry-summary button:hover,
							.entry-summary button:focus,
							input[type="submit"]:hover,
							input[type="submit"]:focus,
							button[type="submit"]:hover,
							button[type="submit"]:focus,
							#primary-search-wrapper .search-container button:hover,
							#primary-search-wrapper .search-container button:focus,
							#infinite-handle .ctis-load-more button:hover,
							#infinite-handle .ctis-load-more button:focus,
							nav.navigation.posts-navigation .nav-links a:hover,
							nav.navigation.posts-navigation .nav-links a:focus,
							.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
							.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
							.feature-slider-wrapper .entry-summary a:hover,
							.feature-slider-wrapper .entry-summary a:focus,
							#contact-section input[type="submit"]:hover,
							#contact-section input[type="submit"]:focus,
							.logo-slider-section .owl-prev:hover,
							.logo-slider-section .owl-prev:focus,
							.logo-slider-section .owl-next:hover, 
							.logo-slider-section .owl-next:focus, 
							.product-container a.button:hover,
							.product-container a.button:focus,
							#scrollup:hover,
							#scrollup:focus {
							        color: %1$s;
							}
							.more-link:hover,
							.scrollup a:hover:before,
							.scrollup a:focus:before {
								color: %1$s;
							}',
		),	

		'button_background_hover_color'    => array(
			'label'   => 	esc_html__( 'Button Background Hover Color', 'wen-commerce-pro' ),
			'css'     => 	'.button:hover,
							.button:focus,
							#contact-section.has-background-image input[type="submit"]:hover,
							#contact-section.has-background-image input[type="submit"]:focus,
							#scrollup:hover,
							#scrollup:focus,
							button:hover, 
							button:focus, 
							input[type="submit"]:hover,
							input[type="submit"]:focus,
							.scrollup a:hover,
							.scrollup a:focus,
							.logo-slider-section .owl-prev:hover,
							.logo-slider-section .owl-prev:focus,
							.logo-slider-section .owl-next:hover, 
							.logo-slider-section .owl-next:focus, 
							button[type="submit"]:hover,
							button[type="submit"]:focus,
							.wp-block-button__link:hover,
							.wp-block-button__link:focus,
							.woocommerce .products .product-container .button:hover,
							.woocommerce .products .product-container .button:focus,
							#infinite-handle .ctis-load-more button:hover,
							#infinite-handle .ctis-load-more button:focus,
							.slider-content-wrapper .cycle-next:hover,
							.slider-content-wrapper .cycle-next:focus,
							.slider-content-wrapper .cycle-prev:hover,
							.slider-content-wrapper .cycle-prev:focus,
							.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
							.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
							nav.navigation.posts-navigation .nav-links a:hover,
							nav.navigation.posts-navigation .nav-links a:focus,
							.woocommerce-pagination ul.page-numbers li .page-numbers:hover,
							.woocommerce-pagination ul.page-numbers li .page-numbers:focus,
							.archive-content-wrap .pagination .page-numbers:hover,
							.archive-content-wrap .pagination .page-numbers:focus,
							.feature-slider-wrapper .entry-summary a:hover,
							.feature-slider-wrapper .entry-summary a:focus,
							.home .header-media-section a.more-link:hover,
							#contact-section input[type="submit"]:hover,
							#contact-section input[type="submit"]:focus,
							a.next.page-numbers:hover,
							a.next.page-numbers:focus,
							a.prev.page-numbers:hover,
							a.prev.page-numbers:focus,
							.more-link .more-button:hover,
							.more-link .more-button:focus,
							.promotion-section .more-link:hover,
							.promotion-section .more-link:focus,
							.woocommerce .product-container .added_to_cart.wc-forward:hover,
							.woocommerce .product-container .added_to_cart.wc-forward:focus,
							#hero-section .view-more a.more-link:hover,
							#hero-section .view-more a.more-link:focus,
							#feature-slider-section .more-link:hover,
							#feature-slider-section .more-link:focus {
							    background-color: %1$s;
							}',
		),
		
		'content_color_white'        => array(
			'label'   => 	esc_html__( 'Text Color With Background', 'wen-commerce-pro' ),
			'css'     => 	'ins,
							.demo_store,
							.sticky-post,
							.team-content-section .social-links-menu li a,
							.scroll-down,
							#testimonial-content-section .owl-next:hover,
							#testimonial-content-section .owl-next:focus,
							#testimonial-content-section .owl-prev:hover,
							#testimonial-content-section .owl-prev:focus,
							.woocommerce .custom-header .woocommerce-breadcrumb a,
							.hero-content-wrapper.has-background-image .entry-container,
							.portfolio-content-wrapper .hentry .entry-container a,
							.portfolio-content-wrapper .hentry .entry-container .entry-meta time,
							.portfolio-content-wrapper .hentry .entry-container .entry-summary,
							.custom-header-content .entry-container,
							.custom-header-content .entry-container .entry-title,
							.ewnewsletter.has-background-image .section-title,
							.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .hentry,
							.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .position,
							.slider-content-wrapper.content-frame .entry-container .entry-title a,
							.slider-content-wrapper.content-frame .entry-container .entry-container-wrap .entry-summary,
							.slider-content-wrapper .entry-header .entry-meta .cat-links a:hover,
							aside.footer-widget-area .widget-title,
							.has-background-image .section-title,
							.has-background-image  .entry-container .entry-meta a,
							.has-background-image  .entry-container .entry-title a,
							.has-background-image  .entry-container .entry-title,
							.has-background-image  .entry-container .entry-title span,
							.has-background-image  .entry-container .entry-summary,
							.has-background-image  .entry-container .entry-content,
							.has-background-image .woocommerce-loop-product__title,
							.home .header-media-section a.more-link,
							#countdown-section .section-description p,
							section.wp-block-cover-image h2 a, section.wp-block-cover-image h2 a:hover, 
							section.wp-block-cover-image h2 a:focus, 
							section.wp-block-cover-image h2 a:active, 
							.wp-block-cover-image-text a, .wp-block-cover-image-text a:hover, 
							.wp-block-cover-image-text a:focus, .wp-block-cover-image-text a:active, 
							.wp-block-cover-text a, 
							.wp-block-cover-text a:hover, 
							.wp-block-cover-text a:focus, 
							.wp-block-cover-text a:active,
							.content-color-white .entry-container .entry-title a,
							#hero-section .view-more a.more-link,
							.top-menu-container button.dropdown-toggle,
							.wp-block-cover p:not(.has-text-color),
							.menu-top-toggle.menu-toggle span,
							.site-header-menu .social-navigation ul li a:hover,
							#brands-section .brands-wrapper .entry-header .product_meta a:hover,
							#collection-section .collection-wrapper .entry-meta a:hover,
							.product-container .product_meta,
							.collection-wrapper .product-container span.woocommerce-Price-amount.amount bdi,
							.brands-wrapper .product-container span.woocommerce-Price-amount.amount bdi,
							.header-media .custom-header-content-wrapper a.more-link:hover,
							.menu-top-toggle.menu-toggle.toggled-on span,
							.menu-social-container a,
							.product-container .entry-header .entry-meta .cat-links a:hover,
							.content-color-white .entry-container .entry-title,
							#site-header-top-menu li,
							.content-color-white .entry-container .entry-content,
							#promotion-section .post-thumbnail-background + .content-wrapper .section-title,
							#promotion-section .post-thumbnail-background + .content-wrapper .entry-summary p,
							#promotion-section .post-thumbnail-background + .content-wrapper .entry-content p,
							#promotion-section .section-description,
							#promotion-section .entry-title,
							#promotion-section .entry-content h2,
							#promotion-section .post-thumbnail-background + .content-wrapper .section-description,
							.content-color-white .entry-container .entry-summary,
							.content-color-white .entry-container .entry-content,
							#promotion-section .play-button,
							.brands-wrapper .entry-container .entry-summary,
							.brands-wrapper .entry-container .entry-title a,
							.brands-wrapper .product-container a,
							.collection-wrapper .entry-container .entry-summary,
							.collection-wrapper .entry-container .entry-title a,
							.collection-wrapper .product-container a,
							.promotion-section .more-link,
							.widget-wrap .social-links-menu li a,
							.site-header-cart .cart-contents .count,
							.product-container a.button,
							.has-background-image .products .button,
							#feature-slider-section .owl-nav button:hover:before,
							#feature-slider-section .owl-nav button:focus:before,
							.playlist-content-wrapper .wp-playlist-caption,
							#service-section.has-background-image .hentry .more-link,
							#stats-section.has-background-image .hentry .more-link,
							.skillbar-item .skillbar-bar .skillbar-header,
							.portfolio-content-wrapper .filter-button-group button.is-checked,
							.skillbar-item .skillbar-bar .skillbar-header .entry-title,
							.contact-details a,
							#testimonial-content-section .section-content-wrapper .entry-content:before,
							#countdown-section .section-title,
							a.next.page-numbers,
							a.prev.page-numbers,
							a.next.page-numbers:hover,
							a.prev.page-numbers:hover,
							.more-link .more-button,
							.has-background-image .section-description,
							.header-top-middle p,
							.woocommerce .product-container .added_to_cart.wc-forward,
							#site-header-cart-wrapper a.cart-contents .count,
							#countdown-section .count-down,
							.header-top-right .site-navigation ul,
							.header-top-bar .site-navigation a,
							#social-footer-navigation li a,
							span.header-top-label.menu-label,
							.menu-top-toggle.menu-toggle:before,
							.entry-container.product-container .entry-content,
							#feature-slider-section .owl-nav button,
							.menu-top-toggle.menu-toggle:hover .menu-label,
							.header-media .section-subtitle,
							.header-top-bar .menu-toggle,
							.slider-content-wrapper .entry-meta .byline,
							.wp-block-cover-text strong,
							.widget-area.sidebar .widget.woocommerce .widget_shopping_cart_content li a.remove,
							.woocommerce .cart-subtotal th,
							aside.footer-widget-area .social-navigation a {
									color: %1$s;
							}
							@media screen (min-width:568px) {
								.skill-section.has-background-image .skillbar-header .entry-title,
								.skill-section.has-background-image .skillbar-header .skill-bar-percent,
								#skill-section.has-background-image .section-heading-wrapper .section-title,
								#skill-section.has-background-image .entry-container .section-description,
								#skill-section.has-background-image .entry-container .section-title,
								.skill-section.has-background-image .section-title-wrapper + .section-description p {
									color: %1$s;
								}
							}
							
							.logo-slider-section .owl-carousel .owl-nav .owl-prev,
							.logo-slider-section .owl-carousel .owl-nav .owl-next,
							.brands-wrapper .entry-summary p a,  .collection-wrapper .entry-summary p a,
							#feature-slider-section .owl-nav button {
									border-color: %1$s;
							}',
		),
		
	);

	return apply_filters( 'wen_commerce_color_options', $color_options );
}

/**
 * Customize video play/pause button in the custom header.
 *
 * @param array $settings header video settings.
 */
function wen_commerce_video_controls( $settings ) {
	$settings['l10n']['play'] = '<span class="screen-reader-text">' . esc_html__( 'Play background video', 'wen-commerce-pro' ) . '</span>';
	$settings['l10n']['pause'] = '<span class="screen-reader-text">' . esc_html__( 'Pause background video', 'wen-commerce-pro' ) . '</span>';
	return $settings;
}
add_filter( 'header_video_settings', 'wen_commerce_video_controls' );

/**
 * Registers color schemes for Zubin.
 *
 * Can be filtered with {@see 'wen_commerce_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Background Color
 * 2. Header Text Color
 * 3. Primary Background Color
 * 4. Secondary Background Color
 * 5. Tertiary Background Color
 * 6. Main Text Color
 * 7. Headline/Heading Text Color
 * 8. Header Navigation Color
 * 9. Header Navigation Hover Color
 * 10. Header Media/Featured Slider Color
 * 11. Link Color
 * 12. Link Hover Color
 * 13. Secondary Link Color
 * 14. Tertiary Link Color
 * 15. Border Color
 * 16. Button Background Color
 * 17. Button Text Color
 * 18. Button Hover Background Color
 * 19. Button Hover Text Color
 * 20. Text Color With Background

 *
 * @since 1.0
 *
 * @return array An associative array of color scheme options.
 */
function wen_commerce_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Zubin.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since 1.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'wen_commerce_color_schemes', array(
		'default' => array(
			'label'  => esc_html__( 'Default', 'wen-commerce-pro' ),
			'colors' => array(
				'background_color'         					=> '#ffffff', /* Body Background Color */
				'header_textcolor'                          => '#111111', /* Header Text Color */
				'primary_background_color'         			=> '#ffffff', /* Primary Background Color */
				'secondary_background_color'            	=> '#fafafa', /* Secondary Background Color */
				'tertiary_background_color'            		=> '#111111', /* Tertiary Background Color */
				'main_text_color'             				=> '#666666', /* Main Text Color */
				'secondary_text_color'                      => '#333333', /* Secondary Text Color */
				'heading_text_color'      					=> '#111111', /* Heading Text Color */
				'header_navigation_color'         			=> '#111111', /* Header Navigation Color */
				'header_navigation_hover_color'         	=> '#ec7a5b', /* Header Navigation Hover Color */
				'header_media_slider_text_color'   			=> '#ffffff', /* Header Media-Featured Slider Text Color */
				'link_color'  								=> '#ec7a5b', /* Link Color  */
				'link_hover_color'    						=> '#000000', /* Link Hover Color */
				'secondary_link_color'              		=> '#000000', /* Secondary Link Color */
				'secondary_link_hover_color'              	=> '#ec7a5b', /* Secondary Link Hover Color */
				'tertiary_link_color'              	    	=> '#777777', /* Tertiary Link Color */
				'border_color'             					=> '#eaeaea', /* Border Color */
				'button_background_color'        			=> '#ec7a5b', /* Button Background Color */
				'button_text_color'        					=> '#ffffff', /* Button Text Color */
				'button_background_hover_color'        		=> '#111111', /* Button Background Hover Color */
				'button_text_hover_color'        			=> '#ffffff', /* Button Text Hover Color */
				'content_color_white'        				=> '#ffffff', /* Text Color With Background */
			),
		),
		'dark' => array( /* Dark */
			'label'  => esc_html__( 'Dark', 'wen-commerce-pro' ),
			'colors' => array(
				'background_color'         					=> '#000000', /* Body Background Color */
				'header_textcolor' 						    => '#ffffff', /* Header Text Color */
				'primary_background_color'         			=> '#000000', /* Primary Background Color */
				'secondary_background_color'            	=> '#1b1b1b', /* Secondary Background Color */
				'tertiary_background_color'            		=> '#181717', /* Tertiary Background Color */
				'main_text_color'             				=> '#c1bebe', /* Main Text Color */
				'secondary_text_color'                      => '#eeeeee', /* Secondary Text Color */
				'heading_text_color'      					=> '#ffffff', /* Heading Text Color */
				'header_navigation_color'         			=> '#ffffff', /* Header Navigation Color */
				'header_navigation_hover_color'         	=> '#ec7a5b', /* Header Navigation Hover Color */
				'header_media_slider_text_color'   			=> '#ffffff', /* Header Media-Featured Slider Text Color */
				'link_color'  								=> '#ec7a5b', /* Link Color  */
				'link_hover_color'    						=> '#ffffff', /* Link Hover Color */
				'secondary_link_color'              		=> '#ffffff', /* Secondary Link Color */
				'secondary_link_hover_color'              	=> '#ec7a5b', /* Secondary Link Hover Color */
				'tertiary_link_color'              	    	=> '#d5d5d5', /* Tertiary Link Color */
				'border_color'             					=> '#3c3939', /* Border Color */
				'button_background_color'        			=> '#ec7a5b', /* Button Background Color */
				'button_text_color'        					=> '#ffffff', /* Button Text Color */
				'button_background_hover_color'        		=> '#333333', /* Button Background Hover Color */
				'button_text_hover_color'        			=> '#ffffff', /* Button Text Hover Color */
				'content_color_white'        				=> '#ffffff', /* Text Color With Background */
			),
		),
		'red' => array(
			'label'  => esc_html__( 'Red', 'wen-commerce-pro' ),
			'colors' => array(
				'background_color'         					=> '#bb2c2c', /* Body Background Color */
				'header_textcolor' 					     	=> '#ffffff', /* Header Text Color */
				'primary_background_color'         			=> '#bb2c2c', /* Primary Background Color */
				'secondary_background_color'            	=> '#c62828', /* Secondary Background Color */
				'tertiary_background_color'            		=> '#d81111', /* Tertiary Background Color */
				'main_text_color'             				=> '#e4caca', /* Main Text Color */
				'secondary_text_color'             			=> '#e4caca', /* Secondary Text Color */
				'heading_text_color'      					=> '#ffffff', /* Heading Text Color */
				'header_navigation_color'         			=> '#ffffff', /* Header Navigation Color */
				'header_navigation_hover_color'         	=> '#ec7a5b', /* Header Navigation Hover Color */
				'header_media_slider_text_color'   			=> '#ffffff', /* Header Media-Featured Slider Text Color */
				'link_color'  								=> '#fa8038', /* Link Color  */
				'link_hover_color'    						=> '#ffffff', /* Link Hover Color */
				'secondary_link_color'              		=> '#ffffff', /* Secondary Link Color */
				'secondary_link_hover_color'              	=> '#ffa0a0', /* Secondary Link Hover Color */
				'tertiary_link_color'              	    	=> '#ffffff', /* Tertiary Link Color */
				'border_color'             					=> '#e97777', /* Border Color */
				'button_background_color'        			=> '#fa8038', /* Button Background Color */
				'button_text_color'        					=> '#ffffff', /* Button Text Color */
				'button_background_hover_color'        		=> '#411616', /* Button Background Hover Color */
				'button_text_hover_color'        			=> '#ffffff', /* Button Text Hover Color */
				'content_color_white'        				=> '#ffffff', /* Text Color With Background */
			),
		),
		'blue' => array(
			'label'  => esc_html__( 'Blue', 'wen-commerce-pro' ),
			'colors' => array(
				'background_color'         					=> '#1976d2', /* Body Background Color */
				'header_textcolor' 					    	=> '#ffffff', /* Header Text Color */
				'primary_background_color'         			=> '#1976d2', /* Primary Background Color */
				'secondary_background_color'            	=> '#1565c0', /* Secondary Background Color */
				'tertiary_background_color'            		=> '#0000d7', /* Tertiary Background Color */
				'main_text_color'             				=> '#dde7f0', /* Main Text Color */
				'secondary_text_color'             			=> '#dde7f0', /* SEcondary Text Color */
				'heading_text_color'      					=> '#ffffff', /* Heading Text Color */
				'header_navigation_color'         			=> '#ffffff', /* Header Navigation Color */
				'header_navigation_hover_color'         	=> '#ec7a5b', /* Header Navigation Hover Color */
				'header_media_slider_text_color'   			=> '#ffffff', /* Header Media-Featured Slider Text Color */
				'link_color'  								=> '#fa8038', /* Link Color  */
				'link_hover_color'    						=> '#ffffff', /* Link Hover Color */
				'secondary_link_color'              		=> '#9bc7df', /* Secondary Link Color */
				'secondary_link_hover_color'             	=> '#fa8038', /* Secondary Link Hover Color */
				'tertiary_link_color'              	    	=> '#ffffff', /* Tertiary Link Color */
				'border_color'             					=> '#2a97be', /* Border Color */
				'button_background_color'        			=> '#fa8038', /* Button Background Color */
				'button_text_color'        					=> '#ffffff', /* Button Text Color */
				'button_background_hover_color'        		=> '#178ff2', /* Button Background Hover Color */
				'button_text_hover_color'        			=> '#ffffff', /* Button Text Hover Color */
				'content_color_white'        				=> '#ffffff', /* Text Color With Background */
			),
		),
	) );
}

if ( ! function_exists( 'wen_commerce_get_color_scheme' ) ) :
/**
 * Retrieves the current Zubin color scheme.
 *
 * Create your own wen_commerce_get_color_scheme() function to override in a child theme.
 *
 * @since 1.0
 *
 * @return array An associative array of either the current or default color scheme HEX values.
 */
function wen_commerce_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = wen_commerce_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // wen_commerce_get_color_scheme

if ( ! function_exists( 'wen_commerce_get_color_scheme_choices' ) ) :
	/**
	 * Retrieves an array of color scheme choices registered for Zubin.
	 *
	 * Create your own wen_commerce_get_color_scheme_choices() function to override
	 * in a child theme.
	 *
	 * @since 1.0
	 *
	 * @return array Array of color schemes.
	 */
	function wen_commerce_get_color_scheme_choices() {
		$color_schemes                = wen_commerce_get_color_schemes();
		$color_scheme_control_options = array();

		foreach ( $color_schemes as $color_scheme => $value ) {
			$color_scheme_control_options[ $color_scheme ] = $value['label'];
		}

		return $color_scheme_control_options;
	}
endif; // wen_commerce_get_color_scheme_choices

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since 1.0
 */
function wen_commerce_customize_control_js() {
	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'wen-commerce-color-scheme-control', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/js/color-scheme-control' . $min . '.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), date( 'Ymd-Gis', filemtime( get_template_directory() . '/' .  '/js/color-scheme-control' . $min . '.js' ) ), true );

	$colors['colorScheme'] = wen_commerce_get_color_schemes();

	$color_options = wen_commerce_color_options();

    $color_options = array_merge( array( 'background_color', 'header_textcolor' ), array_keys( $color_options ) );

	$colors['colorOptions'] = $color_options;

	wp_localize_script( 'wen-commerce-color-scheme-control', 'wenCommerceColorMain', $colors );

	wp_enqueue_script( 'wen-commerce-custom-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . '/js/customize-custom-controls' . $min . '.js', array( 'jquery-ui-sortable' ), date( 'Ymd-Gis', filemtime( get_template_directory() . '/' .  '/js/customize-custom-controls' . $min . '.js' ) ), true );

	wp_enqueue_style( 'wen-commerce-custom-controls-css', trailingslashit( esc_url( get_template_directory_uri() ) ) . '/css/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'wen_commerce_customize_control_js' );

/**
 * Enqueues front-end CSS for custom colors.
 *
 * @since 1.0
 *
 * @see wp_add_inline_style()
 */
function wen_commerce_all_color_css() {
	$color_schemes  = wen_commerce_get_color_schemes();
	$color_scheme  = $color_schemes['default']['colors'];

	$css = '';

	$colors = wen_commerce_color_options();

	$next = '';

	foreach ( $colors as $key => $color ) {
		if ( $next === $key ) {
			// Bail the loop if $next is encountered as its value is next value for gradient and it has already been used.
			continue;
		}

		$default_color = $color_scheme[ $key ];

		$value = get_theme_mod( $key, $default_color );

		if ( isset( $color['is_gradient'] ) && $color['is_gradient'] ) {
			$next = $key . '_next';

			$default_color2 = $color_scheme[ $next  ];

			$value2 = get_theme_mod( $next, $default_color2 );

			if ( $value === $default_color && $value2 === $default_color2 ) {
				continue;
			}

			$css .= sprintf( $color['css'], esc_attr( $value ), esc_attr( $value2 ) );
		} else {
			if ( $value === $default_color ) {
				continue;
			}

			$css .= sprintf( $color['css'], esc_attr( $value ) );
		}
	}

	if ( $css ) {
		wp_add_inline_style( 'wen-commerce-block-style', $css );
	}
}
add_action( 'wp_enqueue_scripts', 'wen_commerce_all_color_css', 11 );

/**
 * Enqueues front-end CSS for the Contact and Newsletter background color
 *
 * @since 1.0
 *
 * @see wp_add_inline_style()
 */

/**
 * Converts a HEX value to RGB.
 *
 * @since 1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function wen_commerce_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}
