<?php
/**
 * Countdown options
 *
 * @package Catch Wedding Pro
 */

/**
 * Add countdown options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_countdown_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_commerce_countdown', array(
			'title' => esc_html__( 'Countdown', 'wen-commerce-pro' ),
			'panel' => 'wen_commerce_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'choices'           => wen_commerce_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_bg_image',
			'sanitize_callback' => 'wen_commerce_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Background Image', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'textarea',
		)
	);

	/*Overlay Option for Countdown*/
	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_overlay',
			'default'           => '50',
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Countdown Overlay', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'number',
			'input_attrs'       => array(
				'style' => 'width: 60px;',
				'min'   => 0,
				'max'   => 100,
			),
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              		=> 'wen_commerce_countdown_content_position',
			'default'           		=> 'content-center',
			'sanitize_callback' 		=> 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'choices'           		=> array(
				'content-center' 		=> esc_html__( 'Center', 'wen-commerce-pro' ),
				'content-right'  		=> esc_html__( 'Right', 'wen-commerce-pro' ),
				'content-left'   		=> esc_html__( 'Left', 'wen-commerce-pro' ),
			),
			'label'             => esc_html__( 'Content Position', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_text_alignment',
			'default'           => 'text-aligned-center',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'choices'           => array(
				'text-aligned-right'  => esc_html__( 'Right', 'wen-commerce-pro' ),
				'text-aligned-center' => esc_html__( 'Center', 'wen-commerce-pro' ),
				'text-aligned-left'   => esc_html__( 'Left', 'wen-commerce-pro' ),
			),
			'label'             => esc_html__( 'Text Alignment', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'select',
		)
	);

	$date = new DateTime();

	// Add 10 Days to current Date.
	$date->add( new DateInterval( 'P10D' ) );
	$default =  $date->format( 'Y-m-d h:m:s' );

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_end_date',
			'sanitize_callback' => 'wen_commerce_sanitize_date_time',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'default'           => $default,
			'label'             => esc_html__( 'End Date', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'type'              => 'date_time',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_more_text',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Button Text', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_more_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Button Link', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_countdown_more_target',
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_countdown_active',
			'label'             => esc_html__( 'Open Button Link in New Window/Tab', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_countdown',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);
}
add_action( 'customize_register', 'wen_commerce_countdown_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_commerce_is_countdown_active' ) ) :
	/**
	* Return true if countdown is active
	*
	* @since Catch Wedding Pro 1.0
	*/
	function wen_commerce_is_countdown_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_commerce_countdown_option' )->value();

		return ( wen_commerce_check_section( $enable ) );
	}
endif;
