<?php
/**
 * Featured Slider Options
 *
 * @package WEN_Commerce
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_slider_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_commerce_featured_slider', array(
			'panel' => 'wen_commerce_theme_options',
			'title' => esc_html__( 'Featured Slider', 'wen-commerce-pro' ),
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'choices'           => wen_commerce_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_transition_in',
			'default'           => 'default',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'choices'           => wen_commerce_transition_effects(),
			'label'             => esc_html__( 'Transition In', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_transition_out',
			'default'           => 'default',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'choices'           => wen_commerce_transition_effects(),
			'label'             => esc_html__( 'Transition Out', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_nav',
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'label'             => esc_html__( 'Display nav arrows', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_dots',
			'default'           => 1,
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'label'             => esc_html__( 'Display nav dots', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_autoplay',
			'default'           => 1,
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'label'             => esc_html__( 'Autoplay', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_loop',
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'label'             => esc_html__( 'Loop (Last to first)', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_transition_timeout',
			'default'           => 4,
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'input_attrs'       => array(
				'style'       => 'width: 100px;',
				'min'         => 0,
			),
			'label'             => esc_html__( 'Transition timeout', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'number',
		)
	);

	/*Overlay Option for Slider*/
	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_overlay',
			'default'           => '20',
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'label'             => esc_html__( 'Slider Overlay', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'number',
			'input_attrs'       => array(
				'style' => 'width: 60px;',
				'min'   => 0,
				'max'   => 100,
			),
		)
	);

	$type = wen_commerce_section_type_options();

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_slider_active',
			'choices'           => $type,
			'label'             => esc_html__( 'Select Slider Type', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_number',
			'default'           => '4',
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',

			'active_callback'   => 'wen_commerce_is_slider_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'wen-commerce-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
				'max'   => 20,
				'step'  => 1,
			),
			'label'             => esc_html__( 'No of Slides', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'number',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_content_show',
			'default'           => 'hide-content',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_image_slider_inactive',
			'choices'           => wen_commerce_content_show(),
			'label'             => esc_html__( 'Display Content', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_meta_show',
			'default'           => 'show-meta',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_image_slider_inactive',
			'choices'           => wen_commerce_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_exclude_slider_post',
			'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
			'active_callback'   => 'wen_commerce_is_post_slider_active',
			'label'             => esc_html__( 'Exclude Slider post from Homepage posts', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_featured_slider',
			'custom_control'    => 'WEN_Commerce_Toggle_Control',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_slider_select_category',
			'sanitize_callback' => 'wen_commerce_sanitize_category_list',
			'custom_control'    => 'WEN_Commerce_Multi_Cat',
			'active_callback'   => 'wen_commerce_is_category_slider_active',
			'label'             => esc_html__( 'Select Categories', 'wen-commerce-pro' ),
			'name'              => 'wen_commerce_slider_select_category',
			'section'           => 'wen_commerce_featured_slider',
			'type'              => 'dropdown-categories',
		)
	);

	$slider_number = get_theme_mod( 'wen_commerce_slider_number', 4 );

	for ( $i = 1; $i <= $slider_number ; $i++ ) {
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'WEN_Commerce_Note_Control',
				'active_callback'   => 'wen_commerce_is_slider_active',
				'label'             => esc_html__( 'Slide #', 'wen-commerce-pro' ) . $i,
				'section'           => 'wen_commerce_featured_slider',
				'type'              => 'description',
			)
		);

		// Post Sliders
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_post_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_post',
				'active_callback'   => 'wen_commerce_is_post_slider_active',
				'input_attrs'       => array(
					'style' => 'width: 80px;',
				),
				'label'             => esc_html__( 'Post', 'wen-commerce-pro' ) . ' # ' . $i,
				'section'           => 'wen_commerce_featured_slider',
				'choices'           => wen_commerce_generate_post_array(),
				'type'              => 'select',
			)
		);

		// Page Sliders
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_page_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_post',
				'active_callback'   => 'wen_commerce_is_page_slider_active',
				'label'             => esc_html__( 'Page', 'wen-commerce-pro' ) . ' # ' . $i,
				'section'           => 'wen_commerce_featured_slider',
				'type'              => 'dropdown-pages',
			)
		);

		// Image Sliders
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_image_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_commerce_is_image_slider_active',
				'label'             => esc_html__( 'Image', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_featured_slider',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_commerce_is_image_slider_active',
				'label'             => esc_html__( 'Link', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_featured_slider',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_target_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
				'active_callback'   => 'wen_commerce_is_image_slider_active',
				'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_featured_slider',
				'custom_control'    => 'WEN_Commerce_Toggle_Control',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_title_image_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_commerce_is_slider_active',
				'label'             => esc_html__( 'Title Image', 'wen-commerce-pro' ) . '&nbsp;' . $i,
				'section'           => 'wen_commerce_featured_slider',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_image_slider_active',
				'label'             => esc_html__( 'Title', 'wen-commerce-pro' ) . '&nbsp;' . $i,
				'section'           => 'wen_commerce_featured_slider',
				'type'              => 'text',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_description_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_slider_active',
				'label'             => esc_html__( 'Description', 'wen-commerce-pro' ) . '&nbsp;' . $i,
				'section'           => 'wen_commerce_featured_slider',
				'type'              => 'textarea',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_slider_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_image_slider_active',
				'label'             => esc_html__( 'Content', 'wen-commerce-pro' ) . '&nbsp;' . $i,
				'section'           => 'wen_commerce_featured_slider',
				'type'              => 'textarea',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
	            'name'              => 'wen_commerce_slider_text_' . $i,
	            'sanitize_callback' => 'sanitize_text_field',
	            'active_callback'   => 'wen_commerce_is_image_slider_active',
	            'label'             => esc_html__( 'Button Text', 'wen-commerce-pro' ) . '&nbsp;' . $i,
	            'section'           => 'wen_commerce_featured_slider',
	            'type'              => 'text',
	        )
	    );

	    wen_commerce_register_option( $wp_customize, array(
	            'name'              => 'wen_commerce_slider_link_' . $i,
	            'sanitize_callback' => 'esc_url_raw',
	            'active_callback'   => 'wen_commerce_is_image_slider_active',
	            'label'             => esc_html__( 'Button Link', 'wen-commerce-pro' ) . '&nbsp;' . $i,
	            'section'           => 'wen_commerce_featured_slider',
	        )
	    );

	    wen_commerce_register_option( $wp_customize, array(
	            'name'              => 'wen_commerce_slider_target_' . $i,
	            'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
	            'active_callback'   => 'wen_commerce_is_image_slider_active',
	            'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-commerce-pro' ),
	            'section'           => 'wen_commerce_featured_slider',
	            'custom_control'    => 'WEN_Commerce_Toggle_Control',
	        )
	    );

	} // End for().
}
add_action( 'customize_register', 'wen_commerce_slider_options' );

/** Active Callback Functions */

if ( ! function_exists( 'wen_commerce_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_slider_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_commerce_slider_option' )->value();

		//return true only if previwed page on customizer matches the type option selected
		return wen_commerce_check_section( $enable );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_post_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_commerce_is_slider_active( $control ) && 'post' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_page_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_commerce_is_slider_active( $control ) && 'page' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_commerce_is_slider_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_image_slider_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_commerce_is_slider_active( $control ) && 'custom' === $type );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_image_slider_inactive' ) ) :
	/**
	* Return true if image slider is inactive
	*
	* @since WEN Commerce Pro 1.0
	*/
	function wen_commerce_is_image_slider_inactive( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( wen_commerce_is_slider_active( $control ) && 'custom' !== $type );
	}
endif;
