<?php
/**
 * Why Choose Us options
 *
 * @package WEN_Commerce
 */

/**
 * Add why choose us content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_why_choose_us_options( $wp_customize ) {

    $wp_customize->add_section( 'wen_commerce_why_choose_us', array(
			'title' => esc_html__( 'Why Choose Us', 'wen-commerce-pro' ),
			'panel' => 'wen_commerce_theme_options',
		)
	);

	// Add color scheme setting and control.
	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'choices'           => wen_commerce_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_type',
			'default'           => 'category',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
            'choices'           => wen_commerce_section_type_options(),
			'label'             => esc_html__( 'Type', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_text_align',
			'default'           => 'text-align-center',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
			'choices'           => array(
				'text-align-center' => esc_html__( 'Center', 'wen-commerce-pro' ),
				'text-align-right'  => esc_html__( 'Right', 'wen-commerce-pro' ),
				'text-align-left'   => esc_html__( 'Left', 'wen-commerce-pro' ),
			),
			'label'             => esc_html__( 'Text Alignment', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
			'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
			'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'text',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_description',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
			'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'textarea',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_layout',
			'default'           => 'layout-three',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
			'choices'           => wen_commerce_sections_layout_options(),
			'label'             => esc_html__( 'Select Layout', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'select',
		)
	);

    wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_number',
			'default'           => 3,
			'sanitize_callback' => 'wen_commerce_sanitize_number_range',
			'active_callback'   => 'wen_commerce_is_why_choose_us_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Items is changed', 'wen-commerce-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Items', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'number',
			'transport'         => 'postMessage',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_show',
			'default'           => 'excerpt',
			'sanitize_callback' => 'wen_commerce_sanitize_select',
			'active_callback'   => 'wen_commerce_is_why_choose_us_post_page_category_cpt_content_active',
			'choices'           => wen_commerce_content_show(),
			'label'             => esc_html__( 'Display Content', 'wen-commerce-pro' ),
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'select',
		)
	);

	wen_commerce_register_option( $wp_customize, array(
			'name'              => 'wen_commerce_why_choose_us_select_category',
			'sanitize_callback' => 'wen_commerce_sanitize_category_list',
			'custom_control'    => 'WEN_Commerce_Multi_Cat',
			'active_callback'   => 'wen_commerce_is_why_choose_us_category_content_active',
			'label'             => esc_html__( 'Select Categories', 'wen-commerce-pro' ),
			'name'              => 'wen_commerce_why_choose_us_select_category',
			'section'           => 'wen_commerce_why_choose_us',
			'type'              => 'dropdown-categories',
		)
	);

	$number = get_theme_mod( 'wen_commerce_why_choose_us_number', 3 );

	//loop for why choose us post content
	for ( $i = 1; $i <= $number ; $i++ ) {
		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_post_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'wen_commerce_is_why_choose_us_post_content_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Post', 'wen-commerce-pro' ) . ' ' . $i ,
				'section'           => 'wen_commerce_why_choose_us',
				'choices'           => wen_commerce_generate_post_array(),
				'type'              => 'select'
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_page_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_post',
				'active_callback'   => 'wen_commerce_is_why_choose_us_page_content_active',
				'label'             => esc_html__( 'Why Choose Us Page', 'wen-commerce-pro' ) . ' ' . $i ,
				'section'           => 'wen_commerce_why_choose_us',
				'type'              => 'dropdown-pages',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'WEN_Commerce_Note_Control',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Why Choose Us #', 'wen-commerce-pro' ) .  $i,
				'section'           => 'wen_commerce_why_choose_us',
				'type'              => 'description',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_image_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Image', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_why_choose_us',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_why_choose_us',
				'type'              => 'text',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Content', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_why_choose_us',
				'type'              => 'textarea',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Link', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_why_choose_us',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_more_button_text_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Link Text', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_why_choose_us',
				'type'              => 'text',
			)
		);

		wen_commerce_register_option( $wp_customize, array(
				'name'              => 'wen_commerce_why_choose_us_target_' . $i,
				'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
				'active_callback'   => 'wen_commerce_is_why_choose_us_custom_content_active',
				'label'             => esc_html__( 'Open in New Window/Tab', 'wen-commerce-pro' ),
				'section'           => 'wen_commerce_why_choose_us',
				'custom_control'    => 'WEN_Commerce_Toggle_Control',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'wen_commerce_why_choose_us_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_commerce_is_why_choose_us_active' ) ) :
	/**
	* Return true if why choose us content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_commerce_why_choose_us_option' )->value();

		//return true only if previewed page on customizer matches the type of content option selected
		return ( wen_commerce_check_section( $enable ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_why_choose_us_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_why_choose_us_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_commerce_is_why_choose_us_active( $control ) && ( 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_why_choose_us_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_why_choose_us_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_commerce_is_why_choose_us_active( $control ) && ( 'page' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_why_choose_us_cpt_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_cpt_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_why_choose_us_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_commerce_is_why_choose_us_active( $control ) && ( 'ect-service' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_why_choose_us_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_why_choose_us_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_commerce_is_why_choose_us_active( $control ) && ( 'category' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_why_choose_us_post_page_category_cpt_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_post_page_category_cpt_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_why_choose_us_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_commerce_is_why_choose_us_active( $control ) && ( 'category' === $type || 'page' === $type || 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'wen_commerce_is_why_choose_us_custom_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since 1.0
	*/
	function wen_commerce_is_why_choose_us_custom_content_active( $control ) {
		$type = $control->manager->get_setting( 'wen_commerce_why_choose_us_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( wen_commerce_is_why_choose_us_active( $control ) && 'custom' === $type );
	}
endif;
