<?php
/**
 * Adding support for WooCommerce Products Showcase Option
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}

/**
 * Add WooCommerce Product Showcase Options to customizer
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_commerce_woo_sps( $wp_customize ) {
   $wp_customize->add_section( 'wen_commerce_woo_sps', array(
        'title' => esc_html__( 'WooCommerce Sale Products', 'wen-commerce-pro' ),
        'panel' => 'wen_commerce_theme_options',
    ) );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_option',
            'default'           => 'disabled',
            'sanitize_callback' => 'wen_commerce_sanitize_select',
            'choices'           => wen_commerce_section_visibility_options(),
            'label'             => esc_html__( 'Enable on', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'select',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_tagline',
            'sanitize_callback' => 'wp_kses_post',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Tagline', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'text',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_title',
            'sanitize_callback' => 'wp_kses_post',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Title', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'text',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_description',
            'sanitize_callback' => 'wp_kses_post',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Description', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'textarea',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_number',
            'default'           => 5,
            'sanitize_callback' => 'wen_commerce_sanitize_number_range',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'description'       => esc_html__( 'Save and refresh the page if No. of Products is changed. Set -1 to display all', 'wen-commerce-pro' ),
            'input_attrs'       => array(
                'style' => 'width: 50px;',
                'min'   => -1,
            ),
            'label'             => esc_html__( 'No of Products', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'number',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'               => 'wen_commerce_woo_sps_columns',
            'default'            => 5,
            'sanitize_callback'  => 'wen_commerce_sanitize_number_range',
            'active_callback'    => 'wen_commerce_is_sps_active',
            'description'        => esc_html__( 'Theme supports up to 5 columns', 'wen-commerce-pro' ),
            'label'              => esc_html__( 'No of Columns', 'wen-commerce-pro' ),
            'section'            => 'wen_commerce_woo_sps',
            'type'               => 'number',
            'input_attrs'       => array(
                'style' => 'width: 50px;',
                'min'   => 1,
                'max'   => 5,
            ),
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'               => 'wen_commerce_woo_sps_paginate',
            'default'            => 'false',
            'sanitize_callback'  => 'wen_commerce_sanitize_select',
            'active_callback'    => 'wen_commerce_is_sps_active',
            'label'              => esc_html__( 'Paginate', 'wen-commerce-pro' ),
            'section'            => 'wen_commerce_woo_sps',
            'type'               => 'radio',
            'choices'            => array(
                'false' => esc_html__( 'No', 'wen-commerce-pro' ),
                'true' => esc_html__( 'Yes', 'wen-commerce-pro' ),
            ),
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'               => 'wen_commerce_woo_sps_orderby',
            'default'            => 'date',
            'sanitize_callback'  => 'wen_commerce_sanitize_select',
            'active_callback'    => 'wen_commerce_is_sps_active',
            'label'              => esc_html__( 'Order By', 'wen-commerce-pro' ),
            'section'            => 'wen_commerce_woo_sps',
            'type'               => 'select',
            'choices'            => array(
                'date'       => esc_html__( 'Date - The date the product was published', 'wen-commerce-pro' ),
                'id'         => esc_html__( 'ID - The post ID of the product', 'wen-commerce-pro' ),
                'menu_order' => esc_html__( 'Menu Order - The Menu Order, if set (lower numbers display first)', 'wen-commerce-pro' ),
                'popularity' => esc_html__( 'Popularity - The number of purchases', 'wen-commerce-pro' ),
                'rand'       => esc_html__( 'Random', 'wen-commerce-pro' ),
                'rating'     => esc_html__( 'Rating - The average product rating', 'wen-commerce-pro' ),
                'title'      => esc_html__( 'Title - The product title', 'wen-commerce-pro' ),
            ),
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'               => 'wen_commerce_woo_sps_products_filter',
            'default'            => 'best_selling',
            'sanitize_callback'  => 'wen_commerce_sanitize_select',
            'active_callback'    => 'wen_commerce_is_sps_active',
            'label'              => esc_html__( 'Products Filter', 'wen-commerce-pro' ),
            'section'            => 'wen_commerce_woo_sps',
            'type'               => 'radio',
            'choices'            => array(
                'none'         => esc_html__( 'None', 'wen-commerce-pro' ),
                'on_sale'      => esc_html__( 'Retrieve on sale products', 'wen-commerce-pro' ),
                'best_selling' => esc_html__( 'Retrieve best selling products', 'wen-commerce-pro' ),
                'top_rated'    => esc_html__( 'Retrieve top rated products', 'wen-commerce-pro' ),
            ),
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_featured',
            'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Show only Products that are marked as Featured Products', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'custom_control'    => 'WEN_Commerce_Toggle_Control',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'               => 'wen_commerce_woo_sps_order',
            'default'            => 'DESC',
            'sanitize_callback'  => 'wen_commerce_sanitize_select',
            'active_callback'    => 'wen_commerce_is_sps_active',
            'label'              => esc_html__( 'Order', 'wen-commerce-pro' ),
            'section'            => 'wen_commerce_woo_sps',
            'type'               => 'radio',
            'choices'            => array(
                'ASC'  => esc_html__( 'Ascending', 'wen-commerce-pro' ),
                'DESC' => esc_html__( 'Descending', 'wen-commerce-pro' ),
            ),
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_skus',
            'description'       => esc_html__( 'Comma separated list of product SKUs', 'wen-commerce-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'SKUs', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'text',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_category',
            'description'       => esc_html__( 'Comma separated list of category slugs', 'wen-commerce-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Category', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'textarea',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_text',
            'sanitize_callback' => 'sanitize_text_field',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Button Text', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'type'              => 'text',
        )
    );
    $shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );
    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_link',
            'default'           =>  esc_url( $shop_page_url ),
            'sanitize_callback' => 'esc_url_raw',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Button Link', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
        )
    );

    wen_commerce_register_option( $wp_customize, array(
            'name'              => 'wen_commerce_woo_sps_target',
            'sanitize_callback' => 'wen_commerce_sanitize_checkbox',
            'active_callback'   => 'wen_commerce_is_sps_active',
            'label'             => esc_html__( 'Open Link in New Window/Tab', 'wen-commerce-pro' ),
            'section'           => 'wen_commerce_woo_sps',
            'custom_control'    => 'WEN_Commerce_Toggle_Control',
        )
    );
}
add_action( 'customize_register', 'wen_commerce_woo_sps', 10 );

/** Active Callback Functions **/
if( ! function_exists( 'wen_commerce_is_sps_active' ) ) :
    /**
    * Return true if featured content is active
    *
    * @since Catch_Store Pro 1.0
    */
    function wen_commerce_is_sps_active( $control ) {
        $enable = $control->manager->get_setting( 'wen_commerce_woo_sps_option' )->value();

        return ( wen_commerce_check_section( $enable ) );
    }
endif;
