<?php
/**
 * The template for displaying brands items
 *
 * @package WEN_Commerce
 */	


$wen_commerce_type 		  = get_theme_mod( 'wen_commerce_brands_type', 'category' );
$wen_commerce_number       = get_theme_mod( 'wen_commerce_brands_number', 2 );
$wen_commerce_show_meta    = get_theme_mod( 'wen_commerce_brands_meta_show', 'show-meta' );
$wen_commerce_layout 	  = get_theme_mod( 'wen_commerce_brands_layout', 'layout-two' );

$wen_commerce_post_list    = array();
$wen_commerce_no_of_post   = 0;

$wen_commerce_args = array(
	'post_type'           => 'post',
	'ignore_sticky_posts' => 1, // ignore sticky posts.
);

// Get valid number of posts.
if ( 'post' === $wen_commerce_type || 'page' === $wen_commerce_type || 'product' === $wen_commerce_type ) {
	$wen_commerce_args['post_type'] = $wen_commerce_type;

	for ( $wen_commerce_i = 1; $wen_commerce_i <= $wen_commerce_number; $wen_commerce_i++ ) {
		$wen_commerce_post_id = '';

		if ( 'post' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_brands_post_' . $wen_commerce_i );
		} elseif ( 'page' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_brands_page_' . $wen_commerce_i );
		} elseif ( 'product' === $wen_commerce_type ) {
			$wen_commerce_post_id =  get_theme_mod( 'wen_commerce_brands_product_' . $wen_commerce_i );
		}

		if ( $wen_commerce_post_id && '' !== $wen_commerce_post_id ) {
			$wen_commerce_post_list = array_merge( $wen_commerce_post_list, array( $wen_commerce_post_id ) );

			$wen_commerce_no_of_post++;
		}
	}

	$wen_commerce_args['post__in'] = $wen_commerce_post_list;
	$wen_commerce_args['orderby']  = 'post__in';
} elseif ( 'category' === $wen_commerce_type ) {
	if ( $wen_commerce_cat = get_theme_mod( 'wen_commerce_brands_select_category' ) ) {
		$wen_commerce_args['category__in'] = $wen_commerce_cat;
	}


	$wen_commerce_no_of_post = $wen_commerce_number;
}

if ( 0 === $wen_commerce_no_of_post ) {
	return;
}

$wen_commerce_args['posts_per_page'] = $wen_commerce_no_of_post;

$wen_commerce_loop = new WP_Query( $wen_commerce_args );


if ( $wen_commerce_loop -> have_posts() ) :
	while ( $wen_commerce_loop -> have_posts() ) :
		$wen_commerce_loop -> the_post();

		$wen_commerce_description  = get_theme_mod('wen_commerce_brands_description_' . absint( $wen_commerce_loop->current_post + 1 ) );
		$wen_commerce_button_text  = get_theme_mod('wen_commerce_brands_button_text_' . absint( $wen_commerce_loop->current_post + 1 ) );

		$wen_commerce_post_class = 'hentry';

		$wen_commerce_thumbnail = array( 840, 560 );

		if ( has_post_thumbnail() ) {
			$wen_commerce_thumb_url = get_the_post_thumbnail_url( get_the_ID(), $wen_commerce_thumbnail );
		} else {
			$wen_commerce_thumb_url = trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/images/no-thumb-840x560.jpg';
		}
		?>
		<article id="post-<?php the_ID(); ?>" <?php post_class( $wen_commerce_post_class ); ?>>
			<div class="hentry-inner">
				<div class="post-thumbnail" style="background-image: url( '<?php echo esc_url( $wen_commerce_thumb_url ); ?>' )">
					<a class="cover-link" href="<?php the_permalink(); ?>">
					</a>
				</div>

				<?php 
				if ( wen_commerce_is_woocommerce_activated() &&  'product' === $wen_commerce_type ) {
					$wen_commerce_title = 'woocommerce-loop-product__title';
				} else {
					$wen_commerce_title = 'entry-title';
				}
				 ?>
				<div class="entry-container product-container">
					<header class="entry-header">

						<?php 
						if ( 'show-meta' === $wen_commerce_show_meta  && ( 'post' === $wen_commerce_type || 'category' === $wen_commerce_type || 'product' === $wen_commerce_type || 'featured-content' === $wen_commerce_type ) ) { 
							echo wen_commerce_entry_header();
						}

						the_title( '<h2 class="' . esc_attr( $wen_commerce_title ) . '"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
					</header>

					<?php if ( wen_commerce_is_woocommerce_activated() && 'product' === $wen_commerce_type ) { ?>
						<div class="product-meta">
							<?php woocommerce_template_single_rating(); ?>
							<?php woocommerce_template_single_price(); ?>
						</div>
					<?php } ?>

					<?php if( $wen_commerce_description ) : ?>
						<div class="entry-content">
							<?php echo esc_html( $wen_commerce_description ); ?>
						</div>
					<?php endif; ?>

					<?php if ( $wen_commerce_button_text ) : ?>
						<p class="view-more">
							<a class="button" target="_blank" href="<?php the_permalink(); ?>"><?php echo esc_html( $wen_commerce_button_text ); ?></a>
						</p>
					<?php endif; ?>
				</div><!-- .entry-container -->
			</div><!-- .hentry-inner -->
		</article>
<?php

	endwhile;
	wp_reset_postdata();
endif;
