<?php
/**
 * The template for displaying featured posts on the front page
 *
 * @package WEN_Commerce
 */
$wen_commerce_type = get_theme_mod( 'wen_commerce_featured_content_type', 'category' );
$wen_commerce_number        = get_theme_mod( 'wen_commerce_featured_content_number', 3 );
$wen_commerce_post_list     = array();
$wen_commerce_no_of_post    = 0;

$wen_commerce_args = array(
	'post_type'           => 'post',
	'ignore_sticky_posts' => 1, // ignore sticky posts.
);

// Get valid number of posts.
if ( 'post' === $wen_commerce_type || 'page' === $wen_commerce_type || 'featured-content' === $wen_commerce_type ) {
	$wen_commerce_args['post_type'] = $wen_commerce_type;

	for ( $wen_commerce_i = 1; $wen_commerce_i <= $wen_commerce_number; $wen_commerce_i++ ) {
		$wen_commerce_post_id = '';

		if ( 'post' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_featured_content_post_' . $wen_commerce_i );
		} elseif ( 'page' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_featured_content_page_' . $wen_commerce_i );
		} elseif ( 'featured-content' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_featured_content_cpt_' . $wen_commerce_i );
		}

		if ( $wen_commerce_post_id && '' !== $wen_commerce_post_id ) {
			$wen_commerce_post_list = array_merge( $wen_commerce_post_list, array( $wen_commerce_post_id ) );

			$wen_commerce_no_of_post++;
		}
	}

	$wen_commerce_args['post__in'] = $wen_commerce_post_list;
	$wen_commerce_args['orderby']  = 'post__in';
} elseif ( 'category' === $wen_commerce_type ) {
	if ( $wen_commerce_cat = get_theme_mod( 'wen_commerce_featured_content_select_category' ) ) {
		$wen_commerce_args['category__in'] = $wen_commerce_cat;
	}

	$wen_commerce_no_of_post = $wen_commerce_number;
}

if ( ! $wen_commerce_no_of_post ) {
	return;
}

$wen_commerce_args['posts_per_page'] = $wen_commerce_no_of_post;

$wen_commerce_loop = new WP_Query( $wen_commerce_args );

$wen_commerce_show_content = get_theme_mod( 'wen_commerce_featured_content_show', 'excerpt' );
$wen_commerce_layout       = get_theme_mod( 'wen_commerce_featured_content_layout', 'layout-three' );

while ( $wen_commerce_loop->have_posts() ) :
	
	$wen_commerce_loop->the_post();

	?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<div class="hentry-inner">
			<?php
			if ( 'layout-one' === $wen_commerce_layout ) {
				$wen_commerce_thumbnail = 'wen-commerce-slider';
			} else {
				$wen_commerce_thumbnail = 'post-thumbnail';
			}

			wen_commerce_post_thumbnail( $wen_commerce_thumbnail );
			?>

			<div class="entry-container">
				<header class="entry-header">
					<?php if ( 'post' === get_post_type() || 'featured-content' === get_post_type() ) : ?>
					<div class="entry-meta">
						<?php wen_commerce_by_line(); ?>

						<?php wen_commerce_cat_list(); ?>
					</div><!-- .entry-meta -->
					<?php endif; ?>
					
					<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
				</header>
				
				<?php wen_commerce_content_display( $wen_commerce_show_content ); ?>
			</div><!-- .entry-container -->
		</div><!-- .hentry-inner -->
	</article>
<?php
endwhile;

wp_reset_postdata();
