<?php
/**
 * The template for displaying portfolio items
 *
 * @package WEN_Commerce
 */
?>

<?php
$wen_commerce_enable = get_theme_mod( 'wen_commerce_portfolio_option', 'disabled' );

if ( ! wen_commerce_check_section( $wen_commerce_enable ) ) {
	// Bail if portfolio section is disabled.
	return;
}

$wen_commerce_type     = get_theme_mod( 'wen_commerce_portfolio_type', 'category' );
$wen_commerce_subtitle = get_theme_mod( 'wen_commerce_portfolio_sub_title' );

$wen_commerce_title       = get_theme_mod( 'wen_commerce_portfolio_title');
$wen_commerce_description = get_theme_mod( 'wen_commerce_portfolio_description' );

if ( 'jetpack-portfolio' === $wen_commerce_type ) {
	$wen_commerce_title       = get_option( 'jetpack_portfolio_title', esc_html__( 'Projects', 'wen-commerce-pro' ) );
	$wen_commerce_description = get_option( 'jetpack_portfolio_content' );
}

if ( ! $wen_commerce_title && ! $wen_commerce_description && ! $wen_commerce_subtitle ) {
	$wen_commerce_classes[] = 'no-section-heading';
}

$wen_commerce_layout = get_theme_mod( 'wen_commerce_portfolio_layout', 'layout-three' );

$wen_commerce_classes[] = $wen_commerce_layout;
$wen_commerce_classes[] = $wen_commerce_type;
$wen_commerce_classes[] = 'section';
?>

<div id="portfolio-content-section" class="portfolio-content-section <?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $wen_commerce_subtitle || $wen_commerce_title || $wen_commerce_description ) : ?>
			<div class="section-heading-wrapper">

				<?php if( $wen_commerce_subtitle ) : ?>
					<div class="section-subtitle">
						<?php echo esc_html( $wen_commerce_subtitle ); ?>
					</div>
				<?php endif; ?>

				<?php if ( $wen_commerce_title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"wen_commerce_><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $wen_commerce_description ) : ?>
					<div class="section-description">
						<p>
							<?php
								echo wp_kses_post( $wen_commerce_description );
							?>
						</p>
					</div><!-- .section-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper portfolio-content-wrapper <?php echo esc_attr( $wen_commerce_layout ); ?>">

			<?php if ( 'category' === $wen_commerce_type && ! empty( $wen_commerce_cats = get_theme_mod( 'wen_commerce_portfolio_select_category' ) ) ) : ?>
			<div class="filter-button-group button-group">
				<button class="button is-checked" data-filter="*"><?php esc_html_e( 'Show All', 'wen-commerce-pro' ) ?></button>
				<?php
				foreach ( $wen_commerce_cats as $wen_commerce_cat ) {
					$wen_commerce_catinfo = get_category( $wen_commerce_cat );
					?>
					<button class="button" data-filter=".<?php echo esc_attr( $wen_commerce_catinfo->slug ); ?>"><?php echo esc_html( $wen_commerce_catinfo->name ); ?></button>
					<?php
				}
			    ?>
			</div>
			<?php endif;?>

			<div class="grid">
				<?php
				if ( 'post' === $wen_commerce_type || 'jetpack-portfolio' === $wen_commerce_type || 'page' === $wen_commerce_type || 'category' === $wen_commerce_type  ) {
					get_template_part( 'template-parts/portfolio/post-types', 'portfolio' );
				} elseif ( 'custom' === $wen_commerce_type ) {
					get_template_part( 'template-parts/portfolio/image', 'portfolio' );
				}
				?>
			</div><!-- .grid -->
		</div><!-- .section-content-wrap -->

		<?php
			$wen_commerce_target = get_theme_mod( 'wen_commerce_portfolio_target' ) ? '_blank': '_self';
			$wen_commerce_link   = get_theme_mod( 'wen_commerce_portfolio_link', '#' );
			$wen_commerce_text   = get_theme_mod( 'wen_commerce_portfolio_text' );

			if ( $wen_commerce_text ) :
		?>

		<p class="view-more">
			<a class="button" target="<?php echo $wen_commerce_target; ?>" href="<?php echo esc_url( $wen_commerce_link ); ?>"><?php echo esc_html( $wen_commerce_text ); ?></a>
		</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- #portfolio-section -->
