<?php
/**
 * The template used for displaying slider
 *
 * @package WEN_Commerce
 */

$wen_commerce_quantity      = get_theme_mod( 'wen_commerce_slider_number', 4 );
$wen_commerce_no_of_post    = 0; // for number of posts
$wen_commerce_post_list     = array(); // list of valid post/page ids
$wen_commerce_type = get_theme_mod( 'wen_commerce_slider_type', 'category' );
$wen_commerce_show_content  = get_theme_mod( 'wen_commerce_slider_content_show', 'hide-content' );
$wen_commerce_show_meta     = get_theme_mod( 'wen_commerce_slider_meta_show', 'show-meta' );

$wen_commerce_args = array(
	'post_type'           => 'any',
	'orderby'             => 'post__in',
	'ignore_sticky_posts' => 1, // ignore sticky posts
);
//Get valid number of posts
if ( 'post' === $wen_commerce_type || 'page' === $wen_commerce_type ) {
	for ( $wen_commerce_i = 1; $wen_commerce_i <= $wen_commerce_quantity; $wen_commerce_i++ ) {
		$wen_commerce_post_id = '';

		if ( 'post' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_slider_post_' . $wen_commerce_i );
		} elseif ( 'page' === $wen_commerce_type ) {
			$wen_commerce_post_id = get_theme_mod( 'wen_commerce_slider_page_' . $wen_commerce_i );
		}

		if ( $wen_commerce_post_id && '' !== $wen_commerce_post_id ) {
			$wen_commerce_post_list = array_merge( $wen_commerce_post_list, array( $wen_commerce_post_id ) );

			$wen_commerce_no_of_post++;
		}
	}

	$wen_commerce_args['post__in'] = $wen_commerce_post_list;
} elseif ( 'category' === $wen_commerce_type ) {
	$wen_commerce_no_of_post = $wen_commerce_quantity;

	$wen_commerce_args['category__in'] = get_theme_mod( 'wen_commerce_slider_select_category' );

	$wen_commerce_args['post_type'] = 'post';
} elseif ( 'tag' === $wen_commerce_type ) {
	$wen_commerce_no_of_post = $wen_commerce_quantity;

	$wen_commerce_args['tag__in'] = get_theme_mod( 'wen_commerce_slider_select_tag' );

	$wen_commerce_args['post_type'] = 'post';
}

if ( ! $wen_commerce_no_of_post ) {
	return;
}

$wen_commerce_args['posts_per_page'] = $wen_commerce_no_of_post;

$wen_commerce_loop = new WP_Query( $wen_commerce_args );

while ( $wen_commerce_loop->have_posts() ) :
	$wen_commerce_loop->the_post();

	$wen_commerce_thumbnail = 'wen-commerce-slider';	
	?>
	<article class="<?php echo esc_attr( 'post post-' . get_the_ID() . ' hentry slides' ); ?>">
		<div class="hentry-inner">
			<div class="slider-image-wrapper">
				<a class="cover-link" title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>">
					<?php 
					if  ( has_post_thumbnail() ) {
						the_post_thumbnail( 'wen-commerce-slider' );
					} else {
						echo '<img class="wp-post-image" src="' . trailingslashit( get_template_directory_uri() ) . '/images/no-thumb-1920x1080.jpg"/>';
					}
					?>
				</a>
			</div><!-- .slider-image-wrapper -->

			<div class="slider-content-wrapper">
				<div class="entry-container">
					<header class="entry-header">
						<?php 
						if ( 'show-meta' === $wen_commerce_show_meta  && ( 'post' === $wen_commerce_type || 'category' === $wen_commerce_type || 'tag' === $wen_commerce_type ) ) {
							echo wen_commerce_slider_entry_category();
						}
						?>
						
						<h2 class="entry-title">
							<a title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>">
								<?php 
								$wen_commerce_title_image = get_theme_mod( 'wen_commerce_slider_title_image_' . ( $wen_commerce_loop->current_post  + 1 ) );

								if ( $wen_commerce_title_image ) : 
								?>
								<span class="title-image"><img src="<?php echo esc_url( $wen_commerce_title_image ); ?>" title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>"/></span>
								<?php endif; ?>

								<?php the_title( '<span class="title-text">','</span>' ); ?>			
							</a>
						</h2>

						<?php 
						$wen_commerce_description = get_theme_mod( 'wen_commerce_slider_description_' . ( $wen_commerce_loop->current_post  + 1 ) );

						if ( $wen_commerce_description ) : ?>
							<div class="description"><?php echo wp_kses_post( $wen_commerce_description ); ?></div>
						<?php 
						endif;	
						?>			
								
						<?php 
						if ( 'show-meta' === $wen_commerce_show_meta  && ( 'post' === $wen_commerce_type || 'category' === $wen_commerce_type || 'tag' === $wen_commerce_type) ) {
							echo wen_commerce_entry_date_author();
						}
						?>
					</header>

					<?php wen_commerce_content_display( $wen_commerce_show_content ); ?>
				</div><!-- .entry-container -->
			</div><!-- .slider-content-wrapper -->
		</div><!-- .hentry-inner -->
	</article><!-- .slides -->
<?php
endwhile;

wp_reset_postdata();
