<?php
/**
 * The template for displaying testimonial items
 *
 * @package WEN_Commerce
 */

$wen_commerce_enable            = get_theme_mod( 'wen_commerce_testimonial_option', 'disabled' );
$wen_commerce_subtitle = get_theme_mod( 'wen_commerce_testimonial_sub_title' );

if ( ! wen_commerce_check_section( $wen_commerce_enable ) ) {
	// Bail if featured content is disabled
	return;
}

$wen_commerce_type = get_theme_mod( 'wen_commerce_testimonial_type', 'category' );

if ( 'jetpack-testimonial' === $wen_commerce_type ) {
	// Get Jetpack options for testimonial.
	$wen_commerce_jetpack_defaults = array(
		'page-title' => esc_html__( 'Testimonials', 'wen-commerce-pro' ),
	);

	// Get Jetpack options for testimonial.
	$wen_commerce_jetpack_options = get_theme_mod( 'jetpack_testimonials', $wen_commerce_jetpack_defaults );

	$wen_commerce_title       = isset( $wen_commerce_jetpack_options['page-title'] ) ? $wen_commerce_jetpack_options['page-title'] : esc_html__( 'Testimonials', 'wen-commerce-pro' );
	$wen_commerce_description = isset( $wen_commerce_jetpack_options['page-content'] ) ? $wen_commerce_jetpack_options['page-content'] : '';
} else {
	$wen_commerce_title       = get_theme_mod( 'wen_commerce_testimonial_title' );
	$wen_commerce_description = get_theme_mod( 'wen_commerce_testimonial_description' );
}

$wen_commerce_classes[] = 'section testimonial-content-section';

if ( ! $wen_commerce_subtitle && ! $wen_commerce_title && ! $wen_commerce_description ) {
	$wen_commerce_classes[] = 'no-section-heading';
}
?>

<div id="testimonial-content-section" class="<?php echo esc_attr( implode( ' ', $wen_commerce_classes ) ); ?>">
	<div class="wrapper">
		<div class="full-content-wrap full-width">

			<?php if ( $wen_commerce_subtitle || $wen_commerce_title || $wen_commerce_description ) : ?>
				<div class="section-heading-wrapper">

					<?php if( $wen_commerce_subtitle ) : ?>
						<div class="section-subtitle">
							<?php echo esc_html( $wen_commerce_subtitle ); ?>
						</div>
					<?php endif; ?>

					<?php if ( $wen_commerce_title ) : ?>
						<div class="section-title-wrapper">
							<h2 class="section-title"wen_commerce_><?php echo wp_kses_post( $wen_commerce_title ); ?></h2>
						</div><!-- .page-title-wrapper -->
					<?php endif; ?>

					<?php if ( $wen_commerce_description ) : ?>
						<div class="section-description">
							<p>
								<?php
									echo wp_kses_post( $wen_commerce_description );
								?>
							</p>
						</div><!-- .section-description-wrapper -->
					<?php endif; ?>
				</div><!-- .section-heading-wrapper -->
			<?php endif; ?>

			<?php 
			
			$wen_commerce_content_classes = 'section-content-wrapper testimonial-content-wrapper';

			$wen_commerce_content_classes .= ' testimonial-slider owl-carousel';

			if ( get_theme_mod( 'wen_commerce_testimonial_dots', 1 ) ) {
				$wen_commerce_content_classes .= ' owl-dots-enabled';
			} 
			?>

			<div class="<?php echo esc_attr( $wen_commerce_content_classes ); ?>">
				<?php
				if ( 'post' === $wen_commerce_type || 'jetpack-testimonial' === $wen_commerce_type || 'page' === $wen_commerce_type || 'category' === $wen_commerce_type || 'tag' === $wen_commerce_type ) {
					get_template_part( 'template-parts/testimonial/post-types-testimonial' );
				} elseif ( 'custom' === $wen_commerce_type ) {
					get_template_part( 'template-parts/testimonial/custom-testimonial' );
				}
				?>
			</div><!-- .section-content-wrapper -->
		</div><!-- .full-content-wrap -->
	</div><!-- .wrapper -->
</div><!-- .testimonial-content-section -->
